# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BANDPASS_METADATA = Metadata(
    id="1ead95475e438c9cee52f9260b62b33c11f2d0ac.boutiques",
    name="3dBandpass",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBandpassOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_bandpass(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output file from 3dbandpass."""
    out_file_: OutputPathType
    """Output file."""


def v_3d_bandpass(
    highpass: float,
    lowpass: float,
    in_file: InputPathType,
    mask: InputPathType | None = None,
    automask: bool = False,
    blur: float | None = None,
    despike: bool = False,
    local_pv: float | None = None,
    nfft: int | None = None,
    no_detrend: bool = False,
    normalize: bool = False,
    notrans: bool = False,
    orthogonalize_dset: InputPathType | None = None,
    orthogonalize_file: list[InputPathType] | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    tr: float | None = None,
    runner: Runner | None = None,
) -> V3dBandpassOutputs:
    """
    Program to lowpass and/or highpass each voxel time series in a dataset, offering
    more/different options than Fourier.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dBandpass.html
    
    Args:
        highpass: Highpass.
        lowpass: Lowpass.
        in_file: Input file to 3dbandpass.
        mask: Mask file.
        automask: Create a mask from the input dataset.
        blur: Blur (inside the mask only) with a filter width (fwhm) of 'fff'\
            millimeters.
        despike: Despike each time series before other processing. hopefully,\
            you don't actually need to do this, which is why it is optional.
        local_pv: Replace each vector by the local principal vector (aka first\
            singular vector) from a neighborhood of radius 'rrr' millimeters. note\
            that the pv time series is l2 normalized. this option is mostly for bob\
            cox to have fun with.
        nfft: Set the fft length [must be a legal value].
        no_detrend: Skip the quadratic detrending of the input that occurs\
            before the fft-based bandpassing. you would only want to do this if the\
            dataset had been detrended already in some other program.
        normalize: Make all output time series have l2 norm = 1 (i.e., sum of\
            squares = 1).
        notrans: Don't check for initial positive transients in the data. the\
            test is a little slow, so skipping it is ok, if you know the data time\
            series are transient-free.
        orthogonalize_dset: Orthogonalize each voxel to the corresponding voxel\
            time series in dataset 'fset', which must have the same spatial and\
            temporal grid structure as the main input dataset. at present, only one\
            '-dsort' option is allowed.
        orthogonalize_file: Also orthogonalize input to columns in f.1d.\
            multiple '-ort' options are allowed.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        tr: Set time step (tr) in sec [default=from dataset header].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBandpassOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BANDPASS_METADATA)
    cargs = []
    cargs.append("3dBandpass")
    cargs.append(str(highpass))
    cargs.append(str(lowpass))
    cargs.append("[OUT_FILE]")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.append(execution.input_file(in_file))
    if automask:
        cargs.append("-automask")
    if blur is not None:
        cargs.extend([
            "-blur",
            str(blur)
        ])
    if despike:
        cargs.append("-despike")
    if local_pv is not None:
        cargs.extend([
            "-localPV",
            str(local_pv)
        ])
    if nfft is not None:
        cargs.extend([
            "-nfft",
            str(nfft)
        ])
    if no_detrend:
        cargs.append("-nodetrend")
    if normalize:
        cargs.append("-norm")
    if notrans:
        cargs.append("-notrans")
    if orthogonalize_dset is not None:
        cargs.extend([
            "-dsort",
            execution.input_file(orthogonalize_dset)
        ])
    if orthogonalize_file is not None:
        cargs.extend([
            "-ort",
            *[execution.input_file(f) for f in orthogonalize_file]
        ])
    if outputtype is not None:
        cargs.append(outputtype)
    if tr is not None:
        cargs.extend([
            "-dt",
            str(tr)
        ])
    ret = V3dBandpassOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_bp"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBandpassOutputs",
    "V_3D_BANDPASS_METADATA",
    "v_3d_bandpass",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DJUNCT_GLUE_IMGS_VERT_METADATA = Metadata(
    id="0680308ab9507fccff69a60f790ac39934121936.boutiques",
    name="@djunct_glue_imgs_vert",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDjunctGlueImgsVertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__djunct_glue_imgs_vert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Output image file with glued images"""


def v__djunct_glue_imgs_vert(
    bottom_image: InputPathType,
    top_image: InputPathType,
    output_file: str,
    viewer_flag: bool = False,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> VDjunctGlueImgsVertOutputs:
    """
    This script helps in gluing two images together vertically.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@djunct_glue_imgs_vert.html
    
    Args:
        bottom_image: Bottom image file.
        top_image: Top image file.
        output_file: Output file prefix.
        viewer_flag: Open in image viewer.
        help_flag: Display help message.
        version_flag: Show version information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDjunctGlueImgsVertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DJUNCT_GLUE_IMGS_VERT_METADATA)
    cargs = []
    cargs.append("adjunct_glue_imgs_vert")
    if viewer_flag:
        cargs.append("-hview")
    if help_flag:
        cargs.append("-help")
    if version_flag:
        cargs.append("-ver")
    cargs.extend([
        "-imbot",
        execution.input_file(bottom_image)
    ])
    cargs.extend([
        "-imtop",
        execution.input_file(top_image)
    ])
    cargs.extend([
        "-prefix",
        output_file
    ])
    ret = VDjunctGlueImgsVertOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDjunctGlueImgsVertOutputs",
    "V__DJUNCT_GLUE_IMGS_VERT_METADATA",
    "v__djunct_glue_imgs_vert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DRIVE_AFNI_METADATA = Metadata(
    id="189b3cf933c3ef7aadb2f61deba82c51cdb891cb.boutiques",
    name="@DriveAfni",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDriveAfniOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__drive_afni(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jpg: OutputPathType
    """Output file created by the DriveAfni script"""


def v__drive_afni(
    runner: Runner | None = None,
) -> VDriveAfniOutputs:
    """
    A demo program for driving 'afni' from a script.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@DriveAfni.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDriveAfniOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DRIVE_AFNI_METADATA)
    cargs = []
    cargs.append("DriveAfni")
    ret = VDriveAfniOutputs(
        root=execution.output_file("."),
        output_jpg=execution.output_file("./SavedAxiale.jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDriveAfniOutputs",
    "V__DRIVE_AFNI_METADATA",
    "v__drive_afni",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RMZ_METADATA = Metadata(
    id="6b7bfd257d51dec2f12da456189674a0ac1ddd7e.boutiques",
    name="rmz",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RmzOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rmz(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rmz(
    filenames: list[InputPathType],
    quiet: bool = False,
    hash_flag: float | None = None,
    keep_flag: bool = False,
    runner: Runner | None = None,
) -> RmzOutputs:
    """
    Zeros out files before removing them.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/rmz.html
    
    Args:
        filenames: Files to zero out and remove.
        quiet: Quiet mode.
        hash_flag: Number of times to zero out the files.
        keep_flag: Keep the files instead of removing them.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RmzOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RMZ_METADATA)
    cargs = []
    cargs.append("rmz")
    if quiet:
        cargs.append("-q")
    if hash_flag is not None:
        cargs.extend([
            "-#",
            str(hash_flag)
        ])
    if keep_flag:
        cargs.append("-k")
    cargs.extend([execution.input_file(f) for f in filenames])
    ret = RmzOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RMZ_METADATA",
    "RmzOutputs",
    "rmz",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_EXTREMA_METADATA = Metadata(
    id="9e7499496b90bc55ce78c7099fff5c33d5bb32b6.boutiques",
    name="volume-extrema",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeExtremaPresmooth:
    """
    smooth the volume before finding extrema.
    """
    kernel: float
    """the size of the gaussian smoothing kernel in mm, as sigma by default"""
    opt_fwhm: bool = False
    """kernel size is FWHM, not sigma"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-presmooth")
        cargs.append(str(self.kernel))
        if self.opt_fwhm:
            cargs.append("-fwhm")
        return cargs


@dataclasses.dataclass
class VolumeExtremaThreshold:
    """
    ignore small extrema.
    """
    low: float
    """the largest value to consider for being a minimum"""
    high: float
    """the smallest value to consider for being a maximum"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-threshold")
        cargs.append(str(self.low))
        cargs.append(str(self.high))
        return cargs


class VolumeExtremaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_extrema(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """the output extrema volume"""


def volume_extrema(
    volume_in: InputPathType,
    distance: float,
    volume_out: str,
    presmooth: VolumeExtremaPresmooth | None = None,
    opt_roi_roi_volume: InputPathType | None = None,
    threshold: VolumeExtremaThreshold | None = None,
    opt_sum_subvols: bool = False,
    opt_consolidate_mode: bool = False,
    opt_only_maxima: bool = False,
    opt_only_minima: bool = False,
    opt_subvolume_subvolume: str | None = None,
    runner: Runner | None = None,
) -> VolumeExtremaOutputs:
    """
    Find extrema in a volume file.
    
    Finds extrema in a volume file, such that no two extrema of the same type
    are within <distance> of each other. The extrema are labeled as -1 for
    minima, 1 for maxima, 0 otherwise. If -only-maxima or -only-minima is
    specified, then it will ignore extrema not of the specified type. These
    options are mutually exclusive.
    
    If -sum-subvols is specified, these extrema subvolumes are summed, and the
    output has a single subvolume with this result.
    
    By default, a datapoint is an extrema only if it is more extreme than every
    other datapoint that is within <distance> from it. If -consolidate-mode is
    used, it instead starts by finding all datapoints that are more extreme than
    their immediate neighbors, then while there are any extrema within
    <distance> of each other, take the two extrema closest to each other and
    merge them into one by a weighted average based on how many original extrema
    have been merged into each.
    
    By default, all input subvolumes are used with no smoothing, use -subvolume
    to specify a single subvolume to use, and -presmooth to smooth the input
    before finding the extrema.
    
    Author: Washington University School of Medicin
    
    Args:
        volume_in: volume file to find the extrema of.
        distance: the minimum distance between identified extrema of the same\
            type.
        volume_out: the output extrema volume.
        presmooth: smooth the volume before finding extrema.
        opt_roi_roi_volume: ignore values outside the selected area: the area\
            to find extrema in.
        threshold: ignore small extrema.
        opt_sum_subvols: output the sum of the extrema subvolumes instead of\
            each subvolume separately.
        opt_consolidate_mode: use consolidation of local minima instead of a\
            large neighborhood.
        opt_only_maxima: only find the maxima.
        opt_only_minima: only find the minima.
        opt_subvolume_subvolume: select a single subvolume to find extrema in:\
            the subvolume number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeExtremaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_EXTREMA_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-extrema")
    cargs.append(execution.input_file(volume_in))
    cargs.append(str(distance))
    cargs.append(volume_out)
    if presmooth is not None:
        cargs.extend(presmooth.run(execution))
    if opt_roi_roi_volume is not None:
        cargs.extend([
            "-roi",
            execution.input_file(opt_roi_roi_volume)
        ])
    if threshold is not None:
        cargs.extend(threshold.run(execution))
    if opt_sum_subvols:
        cargs.append("-sum-subvols")
    if opt_consolidate_mode:
        cargs.append("-consolidate-mode")
    if opt_only_maxima:
        cargs.append("-only-maxima")
    if opt_only_minima:
        cargs.append("-only-minima")
    if opt_subvolume_subvolume is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvolume
        ])
    ret = VolumeExtremaOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_EXTREMA_METADATA",
    "VolumeExtremaOutputs",
    "VolumeExtremaPresmooth",
    "VolumeExtremaThreshold",
    "volume_extrema",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLHD_METADATA = Metadata(
    id="946dad538ed0466ae2e4ee9c00ce491f95dedb6d.boutiques",
    name="fslhd",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FslhdOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslhd(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslhd(
    input_file: InputPathType,
    xml_flag: bool = False,
    runner: Runner | None = None,
) -> FslhdOutputs:
    """
    Display header information from a NIFTI file.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/Fslutils#FSLHD
    
    Args:
        input_file: Input NIFTI file.
        xml_flag: Print an XML-style NIFTI header.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslhdOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLHD_METADATA)
    cargs = []
    cargs.append("fslhd")
    if xml_flag:
        cargs.append("-x")
    cargs.append(execution.input_file(input_file))
    ret = FslhdOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLHD_METADATA",
    "FslhdOutputs",
    "fslhd",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_XYZCAT_METADATA = Metadata(
    id="67f42fa386d9d8b7c0ce29a5eefb7066d6a13ca5.boutiques",
    name="3dXYZcat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dXyzcatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_xyzcat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brainfile: OutputPathType | None
    """Output concatenated dataset."""
    output_headerfile: OutputPathType | None
    """Output concatenated dataset header."""


def v_3d_xyzcat(
    datasets: list[InputPathType],
    direction: str | None = None,
    prefix: str | None = None,
    verbose: bool = False,
    runner: Runner | None = None,
) -> V3dXyzcatOutputs:
    """
    Catenates datasets spatially.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dXYZcat.html
    
    Args:
        datasets: Input datasets to concatenate.
        direction: Catenate along direction 'Q' (X, Y, Z, or their synonyms I,\
            J, K).
        prefix: Use 'pname' for the output dataset prefix name.
        verbose: Print out some verbositiness as the program proceeds.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dXyzcatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_XYZCAT_METADATA)
    cargs = []
    cargs.append("3dXYZcat")
    if direction is not None:
        cargs.extend([
            "-dir",
            direction
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if verbose:
        cargs.append("-verb")
    cargs.extend([execution.input_file(f) for f in datasets])
    ret = V3dXyzcatOutputs(
        root=execution.output_file("."),
        output_brainfile=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        output_headerfile=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dXyzcatOutputs",
    "V_3D_XYZCAT_METADATA",
    "v_3d_xyzcat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_PALETTE_METADATA = Metadata(
    id="f570bc0703eb6b0341b022b06117dc2175ee23ae.boutiques",
    name="cifti-palette",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiPalettePosPercent:
    """
    percentage min/max for positive data coloring.
    """
    pos_min__: float
    """the percentile for the least positive data"""
    pos_max__: float
    """the percentile for the most positive data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-pos-percent")
        cargs.append(str(self.pos_min__))
        cargs.append(str(self.pos_max__))
        return cargs


@dataclasses.dataclass
class CiftiPaletteNegPercent:
    """
    percentage min/max for negative data coloring.
    """
    neg_min__: float
    """the percentile for the least negative data"""
    neg_max__: float
    """the percentile for the most negative data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neg-percent")
        cargs.append(str(self.neg_min__))
        cargs.append(str(self.neg_max__))
        return cargs


@dataclasses.dataclass
class CiftiPalettePosUser:
    """
    user min/max values for positive data coloring.
    """
    pos_min_user: float
    """the value for the least positive data"""
    pos_max_user: float
    """the value for the most positive data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-pos-user")
        cargs.append(str(self.pos_min_user))
        cargs.append(str(self.pos_max_user))
        return cargs


@dataclasses.dataclass
class CiftiPaletteNegUser:
    """
    user min/max values for negative data coloring.
    """
    neg_min_user: float
    """the value for the least negative data"""
    neg_max_user: float
    """the value for the most negative data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-neg-user")
        cargs.append(str(self.neg_min_user))
        cargs.append(str(self.neg_max_user))
        return cargs


@dataclasses.dataclass
class CiftiPaletteThresholding:
    """
    set the thresholding.
    """
    type_: str
    """thresholding setting"""
    test: str
    """show values inside or outside thresholds"""
    min_: float
    """lower threshold"""
    max_: float
    """upper threshold"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-thresholding")
        cargs.append(self.type_)
        cargs.append(self.test)
        cargs.append(str(self.min_))
        cargs.append(str(self.max_))
        return cargs


class CiftiPaletteOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_palette(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_palette(
    cifti_in: InputPathType,
    mode: str,
    cifti_out: str,
    opt_column_column: str | None = None,
    pos_percent: CiftiPalettePosPercent | None = None,
    neg_percent: CiftiPaletteNegPercent | None = None,
    pos_user: CiftiPalettePosUser | None = None,
    neg_user: CiftiPaletteNegUser | None = None,
    opt_interpolate_interpolate: typing.Literal["true", "false"] | None = None,
    opt_disp_pos_display: typing.Literal["true", "false"] | None = None,
    opt_disp_neg_display: typing.Literal["true", "false"] | None = None,
    opt_disp_zero_display: typing.Literal["true", "false"] | None = None,
    opt_palette_name_name: str | None = None,
    thresholding: CiftiPaletteThresholding | None = None,
    opt_inversion_type: str | None = None,
    runner: Runner | None = None,
) -> CiftiPaletteOutputs:
    """
    Set palette on a cifti file.
    
    NOTE: The output file must be a different file than the input file.
    
    For scalar maps, by default the palette is changed for every map, specify
    -column to change only one map. Palette settings not specified will be taken
    from the first column for scalar maps, and from the existing file palette
    for other mapping types. The <mode> argument must be one of the following:
    
    MODE_AUTO_SCALE
    MODE_AUTO_SCALE_ABSOLUTE_PERCENTAGE
    MODE_AUTO_SCALE_PERCENTAGE
    MODE_USER_SCALE
    
    The <name> argument to -palette-name must be one of the following:
    
    ROY-BIG-BL
    videen_style
    Gray_Interp_Positive
    Gray_Interp
    PSYCH-FIXED
    RBGYR20
    RBGYR20P
    RYGBR4_positive
    RGRBR_mirror90_pos
    Orange-Yellow
    POS_NEG_ZERO
    red-yellow
    blue-lightblue
    FSL
    power_surf
    black-red
    black-green
    black-blue
    black-red-positive
    black-green-positive
    black-blue-positive
    blue-black-green
    blue-black-red
    red-black-green
    fsl_red
    fsl_green
    fsl_blue
    fsl_yellow
    RedWhiteBlue
    cool-warm
    spectral
    RY-BC-BL
    magma
    JET256
    PSYCH
    PSYCH-NO-NONE
    ROY-BIG
    clear_brain
    fidl
    raich4_clrmid
    raich6_clrmid
    HSB8_clrmid
    POS_NEG
    Special-RGB-Volume
    
    The <type> argument to -thresholding must be one of the following:
    
    THRESHOLD_TYPE_OFF
    THRESHOLD_TYPE_NORMAL
    THRESHOLD_TYPE_FILE
    
    The <test> argument to -thresholding must be one of the following:
    
    THRESHOLD_TEST_SHOW_OUTSIDE
    THRESHOLD_TEST_SHOW_INSIDE
    
    The <type> argument to -inversion must be one of the following:
    
    OFF
    POSITIVE_WITH_NEGATIVE
    POSITIVE_NEGATIVE_SEPARATE
    .
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_in: the cifti input.
        mode: the mapping mode.
        cifti_out: the output cifti file.
        opt_column_column: select a single column for scalar maps: the column\
            number or name.
        pos_percent: percentage min/max for positive data coloring.
        neg_percent: percentage min/max for negative data coloring.
        pos_user: user min/max values for positive data coloring.
        neg_user: user min/max values for negative data coloring.
        opt_interpolate_interpolate: interpolate colors: boolean, whether to\
            interpolate.
        opt_disp_pos_display: display positive data: boolean, whether to\
            display.
        opt_disp_neg_display: display positive data: boolean, whether to\
            display.
        opt_disp_zero_display: display data closer to zero than the min cutoff:\
            boolean, whether to display.
        opt_palette_name_name: set the palette used: the name of the palette.
        thresholding: set the thresholding.
        opt_inversion_type: specify palette inversion: the type of inversion.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiPaletteOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_PALETTE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-palette")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(mode)
    cargs.append(cifti_out)
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    if pos_percent is not None:
        cargs.extend(pos_percent.run(execution))
    if neg_percent is not None:
        cargs.extend(neg_percent.run(execution))
    if pos_user is not None:
        cargs.extend(pos_user.run(execution))
    if neg_user is not None:
        cargs.extend(neg_user.run(execution))
    if opt_interpolate_interpolate is not None:
        cargs.extend([
            "-interpolate",
            opt_interpolate_interpolate
        ])
    if opt_disp_pos_display is not None:
        cargs.extend([
            "-disp-pos",
            opt_disp_pos_display
        ])
    if opt_disp_neg_display is not None:
        cargs.extend([
            "-disp-neg",
            opt_disp_neg_display
        ])
    if opt_disp_zero_display is not None:
        cargs.extend([
            "-disp-zero",
            opt_disp_zero_display
        ])
    if opt_palette_name_name is not None:
        cargs.extend([
            "-palette-name",
            opt_palette_name_name
        ])
    if thresholding is not None:
        cargs.extend(thresholding.run(execution))
    if opt_inversion_type is not None:
        cargs.extend([
            "-inversion",
            opt_inversion_type
        ])
    ret = CiftiPaletteOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_PALETTE_METADATA",
    "CiftiPaletteNegPercent",
    "CiftiPaletteNegUser",
    "CiftiPaletteOutputs",
    "CiftiPalettePosPercent",
    "CiftiPalettePosUser",
    "CiftiPaletteThresholding",
    "cifti_palette",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SURF_TO_VOL_SPACKLE_METADATA = Metadata(
    id="736d03c526aac5fe42e84164c37cd8561fee460d.boutiques",
    name="@surf_to_vol_spackle",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSurfToVolSpackleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__surf_to_vol_spackle(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """The primary output volume file with surface measures projected."""


def v__surf_to_vol_spackle(
    maskset: InputPathType,
    spec: InputPathType,
    surf_a: str,
    surfset: InputPathType,
    prefix: str,
    surf_b: str | None = None,
    normal_vector_length: float | None = None,
    search_radius: float | None = None,
    num_steps: float | None = None,
    keep_temp_files: bool = False,
    max_iters: float | None = None,
    use_mode: bool = False,
    datum_type: str | None = None,
    ignore_unknown_options: bool = False,
    runner: Runner | None = None,
) -> VSurfToVolSpackleOutputs:
    """
    Project data from a surface dataset into a volume primarily using 3dSurf2Vol but
    then filling any holes with an iterative smoothing procedure.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@surf_to_vol_spackle.html
    
    Args:
        maskset: Mask dataset in which to project surface measures.
        spec: Surface specification file with list of surfaces.
        surf_a: Name of the first surface, e.g., smoothwm, pial, etc.
        surfset: Dataset of surface measures.
        prefix: Basename of output. Final name used is prefix.nii.gz.
        surf_b: Name of the second surface. If not included, computes using\
            normal vector.
        normal_vector_length: Normal vector length if only using a single\
            surface (default 2 mm).
        search_radius: Radius for search for mean to fill holes (default 2 mm).
        num_steps: Number of steps on line segments (default 10).
        keep_temp_files: Do not remove any of the temporary files (default is\
            to remove them).
        max_iters: Maximum number of smoothing and filling iterations (default\
            is 4).
        use_mode: Use mode instead of non-zero median (appropriate for ROIs).
        datum_type: Set datum type to byte, short, or float instead of maskset\
            type. Mode triggers -datum short.
        ignore_unknown_options: Ignore additional options that are not needed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSurfToVolSpackleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SURF_TO_VOL_SPACKLE_METADATA)
    cargs = []
    cargs.append("@surf_to_vol_spackle")
    cargs.append(execution.input_file(maskset))
    cargs.append(execution.input_file(spec))
    cargs.append(surf_a)
    if surf_b is not None:
        cargs.append(surf_b)
    cargs.append(execution.input_file(surfset))
    cargs.append(prefix)
    if normal_vector_length is not None:
        cargs.extend([
            "-f_pn_mm",
            str(normal_vector_length)
        ])
    if search_radius is not None:
        cargs.extend([
            "-meanrad",
            str(search_radius)
        ])
    if num_steps is not None:
        cargs.extend([
            "-nsteps",
            str(num_steps)
        ])
    if keep_temp_files:
        cargs.append("-keep_temp_files")
    if max_iters is not None:
        cargs.extend([
            "-maxiters",
            str(max_iters)
        ])
    if use_mode:
        cargs.append("-mode")
    if datum_type is not None:
        cargs.extend([
            "-datum",
            datum_type
        ])
    if ignore_unknown_options:
        cargs.append("-ignore_unknown_options")
    ret = VSurfToVolSpackleOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(prefix + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSurfToVolSpackleOutputs",
    "V__SURF_TO_VOL_SPACKLE_METADATA",
    "v__surf_to_vol_spackle",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__FIX_FSSPHERE_METADATA = Metadata(
    id="d809b1d459bb69ca3f96b857c3d048611b3b21a7.boutiques",
    name="@fix_FSsphere",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VFixFssphereOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__fix_fssphere(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_surface: OutputPathType
    """Corrected surface"""


def v__fix_fssphere(
    runner: Runner | None = None,
) -> VFixFssphereOutputs:
    """
    Tool for fixing errors in FreeSurfer spherical surfaces.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@fix_FSsphere.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VFixFssphereOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__FIX_FSSPHERE_METADATA)
    cargs = []
    cargs.append("@fix_FSsphere")
    cargs.append("<-spec")
    cargs.append("SPEC>")
    cargs.append("<-sphere")
    cargs.append("SPHERE.asc>")
    cargs.append("[-niter")
    cargs.append("NITER]")
    cargs.append("[-lim")
    cargs.append("LIM]")
    cargs.append("[-keep_temp]")
    cargs.append("[-project_first]")
    ret = VFixFssphereOutputs(
        root=execution.output_file("."),
        corrected_surface=execution.output_file("[SPHERE]_fxd.asc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VFixFssphereOutputs",
    "V__FIX_FSSPHERE_METADATA",
    "v__fix_fssphere",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_4SWAP_METADATA = Metadata(
    id="e5570d9e2ac4432fc7c28c15ab79f0523c5a5345.boutiques",
    name="4swap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V4swapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_4swap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_4swap(
    runner: Runner | None = None,
) -> V4swapOutputs:
    """
    Swaps byte quadruples on the listed files.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/4swap.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V4swapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_4SWAP_METADATA)
    cargs = []
    cargs.append("4swap")
    cargs.append("[-q]")
    cargs.append("[FILES...]")
    ret = V4swapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V4swapOutputs",
    "V_4SWAP_METADATA",
    "v_4swap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMASK_TOOL_METADATA = Metadata(
    id="662daec4bd8060186ee58b8de5a4ad81455bbaf8.boutiques",
    name="3dmask_tool",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaskToolOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmask_tool(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType
    """Output image file name."""
    out_file_: OutputPathType
    """Mask file."""


def v_3dmask_tool(
    in_file: InputPathType,
    count_: bool = False,
    datum: typing.Literal["byte", "short", "float"] | None = None,
    dilate_inputs: str | None = None,
    dilate_results: str | None = None,
    fill_dirs: str | None = None,
    fill_holes: bool = False,
    frac: float | None = None,
    inter: bool = False,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    union: bool = False,
    verbose: int | None = None,
    runner: Runner | None = None,
) -> V3dmaskToolOutputs:
    """
    3dmask_tool - for combining/dilating/eroding/filling masks.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dmask_tool.html
    
    Args:
        in_file: Input file to 3dmask_tool.
        count_: Instead of created a binary 0/1 mask dataset, create one with\
            counts of voxel overlap, i.e., each voxel will contain the number of\
            masks that it is set in.
        datum: 'byte' or 'short' or 'float'. Specify data type for output.
        dilate_inputs: Use this option to dilate and/or erode datasets as they\
            are read. ex. '5 -5' to dilate and erode 5 times.
        dilate_results: Dilate and/or erode combined mask at the given levels.
        fill_dirs: Fill holes only in the given directions. this option is for\
            use with -fill holes. should be a single string that specifies 1-3 of\
            the axes using {x,y,z} labels (i.e. dataset axis order), or using the\
            labels in {r,l,a,p,i,s}.
        fill_holes: This option can be used to fill holes in the resulting\
            mask, i.e. after all other processing has been done.
        frac: When combining masks (across datasets and sub-bricks), use this\
            option to restrict the result to a certain fraction of the set of\
            volumes.
        inter: Intersection, this means -frac 1.0.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        union: Union, this means -frac 0.
        verbose: Specify verbosity level, for 0 to 3.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaskToolOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMASK_TOOL_METADATA)
    cargs = []
    cargs.append("3dmask_tool")
    if count_:
        cargs.append("-count")
    cargs.extend([
        "-input",
        execution.input_file(in_file)
    ])
    if datum is not None:
        cargs.extend([
            "-datum",
            datum
        ])
    if dilate_inputs is not None:
        cargs.extend([
            "-dilate_inputs",
            dilate_inputs
        ])
    if dilate_results is not None:
        cargs.extend([
            "-dilate_results",
            dilate_results
        ])
    if fill_dirs is not None:
        cargs.extend([
            "-fill_dirs",
            fill_dirs
        ])
    if fill_holes:
        cargs.append("-fill_holes")
    if frac is not None:
        cargs.extend([
            "-frac",
            str(frac)
        ])
    if inter:
        cargs.append("-inter")
    cargs.append("[OUT_FILE]")
    if outputtype is not None:
        cargs.append(outputtype)
    if union:
        cargs.append("-union")
    if verbose is not None:
        cargs.extend([
            "-verb",
            str(verbose)
        ])
    ret = V3dmaskToolOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(in_file).name + "_mask"),
        out_file_=execution.output_file("out_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaskToolOutputs",
    "V_3DMASK_TOOL_METADATA",
    "v_3dmask_tool",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_AVERAGE_DENSE_ROI_METADATA = Metadata(
    id="c4e840874826cfe093198a63d8044f319d7c2e7e.boutiques",
    name="cifti-average-dense-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiAverageDenseRoiCiftiRoi:
    """
    cifti file containing combined weights.
    """
    roi_cifti: InputPathType
    """the roi cifti file"""
    opt_in_memory: bool = False
    """cache the roi in memory so that it isn't re-read for each input cifti"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cifti-roi")
        cargs.append(execution.input_file(self.roi_cifti))
        if self.opt_in_memory:
            cargs.append("-in-memory")
        return cargs


@dataclasses.dataclass
class CiftiAverageDenseRoiCifti:
    """
    specify an input cifti file.
    """
    cifti_in: InputPathType
    """a cifti file to average across"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cifti")
        cargs.append(execution.input_file(self.cifti_in))
        return cargs


class CiftiAverageDenseRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_average_dense_roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """output cifti dscalar file"""


def cifti_average_dense_roi(
    cifti_out: str,
    cifti_roi: CiftiAverageDenseRoiCiftiRoi | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    opt_left_area_surf_left_surf: InputPathType | None = None,
    opt_right_area_surf_right_surf: InputPathType | None = None,
    opt_cerebellum_area_surf_cerebellum_surf: InputPathType | None = None,
    cifti: list[CiftiAverageDenseRoiCifti] | None = None,
    runner: Runner | None = None,
) -> CiftiAverageDenseRoiOutputs:
    """
    Average cifti rows across subjects by roi.
    
    Averages rows for each map of the ROI(s), across all files. ROI maps are
    treated as weighting functions, including negative values. For efficiency,
    ensure that everything that is not intended to be used is zero in the ROI
    map. If -cifti-roi is specified, -left-roi, -right-roi, -cerebellum-roi, and
    -vol-roi must not be specified. If multiple non-cifti ROI files are
    specified, they must have the same number of columns.
    
    Author: Washington University School of Medicin
    
    Args:
        cifti_out: output cifti dscalar file.
        cifti_roi: cifti file containing combined weights.
        opt_left_roi_roi_metric: weights to use for left hempsphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: weights to use for right hempsphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: weights to use for cerebellum surface:\
            the cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxel weights to use: the roi volume file.
        opt_left_area_surf_left_surf: specify the left surface for vertex area\
            correction: the left surface file.
        opt_right_area_surf_right_surf: specify the right surface for vertex\
            area correction: the right surface file.
        opt_cerebellum_area_surf_cerebellum_surf: specify the cerebellum\
            surface for vertex area correction: the cerebellum surface file.
        cifti: specify an input cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiAverageDenseRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_AVERAGE_DENSE_ROI_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-average-dense-roi")
    cargs.append(cifti_out)
    if cifti_roi is not None:
        cargs.extend(cifti_roi.run(execution))
    if opt_left_roi_roi_metric is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(opt_left_roi_roi_metric)
        ])
    if opt_right_roi_roi_metric is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(opt_right_roi_roi_metric)
        ])
    if opt_cerebellum_roi_roi_metric is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(opt_cerebellum_roi_roi_metric)
        ])
    if opt_vol_roi_roi_vol is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(opt_vol_roi_roi_vol)
        ])
    if opt_left_area_surf_left_surf is not None:
        cargs.extend([
            "-left-area-surf",
            execution.input_file(opt_left_area_surf_left_surf)
        ])
    if opt_right_area_surf_right_surf is not None:
        cargs.extend([
            "-right-area-surf",
            execution.input_file(opt_right_area_surf_right_surf)
        ])
    if opt_cerebellum_area_surf_cerebellum_surf is not None:
        cargs.extend([
            "-cerebellum-area-surf",
            execution.input_file(opt_cerebellum_area_surf_cerebellum_surf)
        ])
    if cifti is not None:
        cargs.extend([a for c in [s.run(execution) for s in cifti] for a in c])
    ret = CiftiAverageDenseRoiOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_AVERAGE_DENSE_ROI_METADATA",
    "CiftiAverageDenseRoiCifti",
    "CiftiAverageDenseRoiCiftiRoi",
    "CiftiAverageDenseRoiOutputs",
    "cifti_average_dense_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__T1SCALE_METADATA = Metadata(
    id="6742db233e7f7fe985fd582e9532fb9d1711e98a.boutiques",
    name="@T1scale",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VT1scaleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__t1scale(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    uniformized_t1_output: OutputPathType
    """Uniformized T1 volume output file"""
    masked_uniformized_t1_output: OutputPathType
    """Masked Uniformized T1 volume output file"""
    aligned_pd_output: OutputPathType
    """Aligned PD volume output file in alignment with T1+orig"""


def v__t1scale(
    align: bool = False,
    head_mask: bool = False,
    unmasked_uni: bool = False,
    masked_uni: bool = False,
    echo: bool = False,
    help_: bool = False,
    h_web: bool = False,
    h_view: bool = False,
    all_opts: bool = False,
    h_find_word: str | None = None,
    runner: Runner | None = None,
) -> VT1scaleOutputs:
    """
    Fix bias field shading in T1 by scaling it with PD image. You can also get a
    decent result even without the PD volume.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@T1scale.html
    
    Args:
        align: Align PD volume to T1. Without this option, PDvol is assumed in\
            alignment with T1vol.
        head_mask: Create mask using 3dSkullStrip's -head option.
        unmasked_uni: Do not apply masking to uniformized volume (default).
        masked_uni: Apply masking to uniformized volume.
        echo: Set echo.
        help_: Display this help message and exit.
        h_web: Open webpage with help for this program.
        h_view: Open -help output in a GUI editor.
        all_opts: List all of the options for this script.
        h_find_word: Search for lines containing WORD in -help output. Search\
            is approximate.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VT1scaleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__T1SCALE_METADATA)
    cargs = []
    cargs.append("@T1scale")
    cargs.append("<-T1")
    cargs.append("T1vol>")
    cargs.append("<-PD")
    cargs.append("PDvol>")
    cargs.append("[OUTPUT_DIR]")
    if align:
        cargs.append("-align")
    cargs.append("[MASK_FILE]")
    if head_mask:
        cargs.append("-head_mask")
    if unmasked_uni:
        cargs.append("-unmasked_uni")
    if masked_uni:
        cargs.append("-masked_uni")
    if echo:
        cargs.append("-echo")
    if help_:
        cargs.append("-help")
    if h_web:
        cargs.append("-h_web")
    if h_view:
        cargs.append("-hview")
    if all_opts:
        cargs.append("-all_opts")
    if h_find_word is not None:
        cargs.extend([
            "-h_find",
            h_find_word
        ])
    ret = VT1scaleOutputs(
        root=execution.output_file("."),
        uniformized_t1_output=execution.output_file("T1.uni+orig"),
        masked_uniformized_t1_output=execution.output_file("T1_uni_masked+orig"),
        aligned_pd_output=execution.output_file("PD+orig"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VT1scaleOutputs",
    "V__T1SCALE_METADATA",
    "v__t1scale",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RE_HO_METADATA = Metadata(
    id="4907b9dfed49d3b0df7f50cea93389d02339c14e.boutiques",
    name="3dReHo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dReHoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_re_ho(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reho_output: OutputPathType
    """Output file containing ReHo/Kendall's W value per voxel."""
    roi_reho_vals: OutputPathType
    """List of ROI ReHo values."""
    chi_square: OutputPathType
    """Optional output subbrick containing Friedman chi-square value per
    voxel."""
    roi_chi_vals: OutputPathType
    """ROI Chi-square values file."""


def v_3d_re_ho(
    prefix: str,
    inset: InputPathType,
    nneigh: str | None = None,
    chi_sq: bool = False,
    mask: InputPathType | None = None,
    neigh_rad: float | None = None,
    neigh_x: float | None = None,
    neigh_y: float | None = None,
    neigh_z: float | None = None,
    box_rad: float | None = None,
    box_x: float | None = None,
    box_y: float | None = None,
    box_z: float | None = None,
    in_rois: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dReHoOutputs:
    """
    3dReHo calculates Kendall's W per voxel using neighborhood voxels from 4D time
    series data set.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dReHo.html
    
    Args:
        prefix: Output file name part.
        inset: Time series input file.
        nneigh: Number of voxels in neighborhood, inclusive; can be 7 (for\
            facewise neighbors), 19 (for face- and edge-wise neighbors), 27 (for\
            face-, edge-, and node-wise neighbors). Default is 27.
        chi_sq: Switch to output Friedman chi-square value per voxel as a\
            subbrick.
        mask: Include a whole brain mask within which to calculate ReHo.\
            Otherwise, data should be masked already.
        neigh_rad: Radius R of a desired neighborhood for voxelwise control,\
            must be a floating point number >1. Examples: R=2.0 -> V=33, R=2.3 ->\
            V=57, etc.
        neigh_x: Semi-radius length A for ellipsoidal neighborhood.
        neigh_y: Semi-radius length B for ellipsoidal neighborhood.
        neigh_z: Semi-radius length C for ellipsoidal neighborhood.
        box_rad: Cubic box radius BR centered on a given voxel for neighborhood\
            control. Examples: BR=1 -> V=27, BR=2 -> V=125, etc.
        box_x: Box volume neighborhood dimension X. Values put in get added in\
            the +/- directions of each axis.
        box_y: Box volume neighborhood dimension Y. Values put in get added in\
            the +/- directions of each axis.
        box_z: Box volume neighborhood dimension Z. Values put in get added in\
            the +/- directions of each axis.
        in_rois: Input a set of ROIs, each labeled with distinct integers. ReHo\
            will be calculated per ROI.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dReHoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RE_HO_METADATA)
    cargs = []
    cargs.append("3dReHo")
    cargs.append("-prefix")
    cargs.append(prefix)
    cargs.append("-inset")
    cargs.append(execution.input_file(inset))
    if nneigh is not None:
        cargs.extend([
            "-nneigh",
            nneigh
        ])
    if chi_sq:
        cargs.append("-chi_sq")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if neigh_rad is not None:
        cargs.extend([
            "-neigh_RAD",
            str(neigh_rad)
        ])
    if neigh_x is not None:
        cargs.extend([
            "-neigh_X",
            str(neigh_x)
        ])
    if neigh_y is not None:
        cargs.extend([
            "-neigh_Y",
            str(neigh_y)
        ])
    if neigh_z is not None:
        cargs.extend([
            "-neigh_Z",
            str(neigh_z)
        ])
    if box_rad is not None:
        cargs.extend([
            "-box_RAD",
            str(box_rad)
        ])
    if box_x is not None:
        cargs.extend([
            "-box_X",
            str(box_x)
        ])
    if box_y is not None:
        cargs.extend([
            "-box_Y",
            str(box_y)
        ])
    if box_z is not None:
        cargs.extend([
            "-box_Z",
            str(box_z)
        ])
    if in_rois is not None:
        cargs.extend([
            "-in_rois",
            execution.input_file(in_rois)
        ])
    ret = V3dReHoOutputs(
        root=execution.output_file("."),
        reho_output=execution.output_file(prefix + "+orig.BRIK"),
        roi_reho_vals=execution.output_file(prefix + "_ROI_reho.vals"),
        chi_square=execution.output_file(prefix + "+orig.BRIK[1]"),
        roi_chi_vals=execution.output_file(prefix + "_ROI_reho.chi"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dReHoOutputs",
    "V_3D_RE_HO_METADATA",
    "v_3d_re_ho",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMRM_METADATA = Metadata(
    id="4baaab2f1f3694642eaa2ba934022c444a043ffa.boutiques",
    name="imrm",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class ImrmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imrm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def imrm(
    images_to_remove: list[str],
    runner: Runner | None = None,
) -> ImrmOutputs:
    """
    Remove specified image files.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        images_to_remove: List of image names to remove. Filenames can be\
            basenames or full names.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImrmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMRM_METADATA)
    cargs = []
    cargs.append("/usr/local/fsl/bin/imrm")
    cargs.extend(images_to_remove)
    ret = ImrmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMRM_METADATA",
    "ImrmOutputs",
    "imrm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

PREPARE_FIELDMAP_METADATA = Metadata(
    id="dad6607f2a51e3a9698a27e3d3875a0624021638.boutiques",
    name="prepare_fieldmap",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PrepareFieldmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `prepare_fieldmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_fieldmap_outfile: OutputPathType | None
    """Output name for prepared fieldmap."""


def prepare_fieldmap(
    in_phase: InputPathType,
    in_magnitude: InputPathType,
    delta_te: float = 2.46,
    scanner: str | None = "SIEMENS",
    out_fieldmap: InputPathType | None = None,
    nocheck: bool = False,
    output_type: typing.Literal["NIFTI", "NIFTI_PAIR", "NIFTI_GZ", "NIFTI_PAIR_GZ"] | None = None,
    runner: Runner | None = None,
) -> PrepareFieldmapOutputs:
    """
    
    Interface for the fsl_prepare_fieldmap script (FSL 5.0)
    Prepares a fieldmap suitable for FEAT from SIEMENS data - saves output in
    rad/s format (e.g. ```fsl_prepare_fieldmap SIEMENS
    images_3_gre_field_mapping images_4_gre_field_mapping fmap_rads 2.65```).
    
    Author: Nipype (interface)
    
    Args:
        in_phase: Phase difference map, in siemens format range from 0-4096 or\
            0-8192).
        in_magnitude: Magnitude difference map, brain extracted.
        delta_te: Echo time difference of the fieldmap sequence in ms. (usually\
            2.46ms in siemens).
        scanner: Must be siemens.
        out_fieldmap: Output name for prepared fieldmap.
        nocheck: Do not perform sanity checks for image size/range/dimensions.
        output_type: 'nifti' or 'nifti_pair' or 'nifti_gz' or 'nifti_pair_gz'.\
            Fsl output type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PrepareFieldmapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(PREPARE_FIELDMAP_METADATA)
    cargs = []
    cargs.append("PrepareFieldmap")
    cargs.append(str(delta_te))
    if scanner is not None:
        cargs.append(scanner)
    cargs.append(execution.input_file(in_phase))
    cargs.append(execution.input_file(in_magnitude))
    if out_fieldmap is not None:
        cargs.append(execution.input_file(out_fieldmap))
    if nocheck:
        cargs.append("--nocheck")
    if output_type is not None:
        cargs.append(output_type)
    ret = PrepareFieldmapOutputs(
        root=execution.output_file("."),
        out_fieldmap_outfile=execution.output_file(pathlib.Path(out_fieldmap).name) if (out_fieldmap is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "PREPARE_FIELDMAP_METADATA",
    "PrepareFieldmapOutputs",
    "prepare_fieldmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_GEODESIC_ROIS_METADATA = Metadata(
    id="7bc1ad5c94477de7322dce3c02d510228788c414.boutiques",
    name="surface-geodesic-rois",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceGeodesicRoisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_geodesic_rois(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric"""


def surface_geodesic_rois(
    surface: InputPathType,
    limit: float,
    vertex_list_file: str,
    metric_out: str,
    opt_gaussian_sigma: float | None = None,
    opt_overlap_logic_method: str | None = None,
    opt_names_name_list_file: str | None = None,
    opt_corrected_areas_area_metric: InputPathType | None = None,
    runner: Runner | None = None,
) -> SurfaceGeodesicRoisOutputs:
    """
    Draw geodesic limited rois at vertices.
    
    For each vertex in the list file, a column in the output metric is created,
    and an ROI around that vertex is drawn in that column. Each metric column
    will have zeros outside the geodesic distance spacified by <limit>, and by
    default will have a value of 1.0 inside it. If the -gaussian option is
    specified, the values inside the ROI will instead form a gaussian with the
    specified value of sigma, normalized so that the sum of the nonzero values
    in the metric column is 1.0. The <method> argument to -overlap-logic must be
    one of ALLOW, CLOSEST, or EXCLUDE. ALLOW is the default, and means that ROIs
    are treated independently and may overlap. CLOSEST means that ROIs may not
    overlap, and that no ROI contains vertices that are closer to a different
    seed vertex. EXCLUDE means that ROIs may not overlap, and that any vertex
    within range of more than one ROI does not belong to any ROI.
    
    Author: Washington University School of Medicin
    
    Args:
        surface: the surface to draw on.
        limit: geodesic distance limit from vertex, in mm.
        vertex_list_file: a text file containing the vertices to draw ROIs\
            around.
        metric_out: the output metric.
        opt_gaussian_sigma: generate a gaussian kernel instead of a flat ROI:\
            the sigma for the gaussian kernel, in mm.
        opt_overlap_logic_method: how to handle overlapping ROIs, default\
            ALLOW: the method of resolving overlaps.
        opt_names_name_list_file: name the columns from text file: a text file\
            containing column names, one per line.
        opt_corrected_areas_area_metric: vertex areas to use instead of\
            computing them from the surface: the corrected vertex areas, as a\
            metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGeodesicRoisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GEODESIC_ROIS_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-geodesic-rois")
    cargs.append(execution.input_file(surface))
    cargs.append(str(limit))
    cargs.append(vertex_list_file)
    cargs.append(metric_out)
    if opt_gaussian_sigma is not None:
        cargs.extend([
            "-gaussian",
            str(opt_gaussian_sigma)
        ])
    if opt_overlap_logic_method is not None:
        cargs.extend([
            "-overlap-logic",
            opt_overlap_logic_method
        ])
    if opt_names_name_list_file is not None:
        cargs.extend([
            "-names",
            opt_names_name_list_file
        ])
    if opt_corrected_areas_area_metric is not None:
        cargs.extend([
            "-corrected-areas",
            execution.input_file(opt_corrected_areas_area_metric)
        ])
    ret = SurfaceGeodesicRoisOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_GEODESIC_ROIS_METADATA",
    "SurfaceGeodesicRoisOutputs",
    "surface_geodesic_rois",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DICE_METRIC_METADATA = Metadata(
    id="1e8709949dd1f81bc9b0adf1a50b0355570f9576.boutiques",
    name="@DiceMetric",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiceMetricOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__dice_metric(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__dice_metric(
    keep_tmp: bool = False,
    runner: Runner | None = None,
) -> VDiceMetricOutputs:
    """
    Computes Dice Metric between BASE and each of the DSET volumes.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@DiceMetric.html
    
    Args:
        keep_tmp: Keep temporary files for debugging. Note that you should\
            delete temporary files before rerunning the script.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiceMetricOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DICE_METRIC_METADATA)
    cargs = []
    cargs.append("@DiceMetric")
    cargs.append("<-base")
    cargs.append("BASE>")
    cargs.append("<-dsets")
    cargs.append("DSET1")
    cargs.append("[DSET2")
    cargs.append("...]>")
    cargs.append("[max_N_roi")
    cargs.append("MAX_ROI]")
    if keep_tmp:
        cargs.append("-keep_tmp")
    cargs.append("[OPTIONS...]")
    ret = VDiceMetricOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiceMetricOutputs",
    "V__DICE_METRIC_METADATA",
    "v__dice_metric",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_SMOOTHING_METADATA = Metadata(
    id="319b96fa1a49eafcf799a92cf9d29e576ce50d4e.boutiques",
    name="surface-smoothing",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceSmoothingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_smoothing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    surface_out: OutputPathType
    """output surface file"""


def surface_smoothing(
    surface_in: InputPathType,
    smoothing_strength: float,
    smoothing_iterations: int,
    surface_out: str,
    runner: Runner | None = None,
) -> SurfaceSmoothingOutputs:
    """
    Surface smoothing.
    
    Smooths a surface by averaging vertex coordinates with those of the
    neighboring vertices.
    
    Author: Washington University School of Medicin
    
    Args:
        surface_in: the surface file to smooth.
        smoothing_strength: smoothing strength (ranges [0.0 - 1.0]).
        smoothing_iterations: smoothing iterations.
        surface_out: output surface file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceSmoothingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_SMOOTHING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-smoothing")
    cargs.append(execution.input_file(surface_in))
    cargs.append(str(smoothing_strength))
    cargs.append(str(smoothing_iterations))
    cargs.append(surface_out)
    ret = SurfaceSmoothingOutputs(
        root=execution.output_file("."),
        surface_out=execution.output_file(surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_SMOOTHING_METADATA",
    "SurfaceSmoothingOutputs",
    "surface_smoothing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_FWHM_METADATA = Metadata(
    id="34840e1bbf88f386954becc95ba3a4074cff6110.boutiques",
    name="SurfFWHM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfFwhmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_fwhm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    detrended_output: OutputPathType | None
    """Detrended dataset."""
    main_output: OutputPathType | None
    """Main output dataset."""
    histogram_output: OutputPathType | None
    """Histogram showing the distribution of local FWHM."""
    mask_output: OutputPathType | None
    """Mask output dataset."""


def surf_fwhm(
    input_file: InputPathType,
    mask: InputPathType | None = None,
    surf_1: str | None = None,
    surf_sphere: str | None = None,
    clean: bool = False,
    detrend: float | None = None,
    detpoly: float | None = None,
    detprefix: str | None = None,
    prefix: str | None = None,
    vox_size: float | None = None,
    neighborhood: float | None = None,
    ok_warn: bool = False,
    examples: bool = False,
    slice_: bool = False,
    runner: Runner | None = None,
) -> SurfFwhmOutputs:
    """
    A program for calculating local and global FWHM.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfFWHM.html
    
    Args:
        input_file: Dataset for which the FWHM is to be calculated.
        mask: Node mask so that only nodes in the mask are used to obtain\
            estimates.
        surf_1: Option for specifying the surface over which the input dataset\
            is defined.
        surf_sphere: Spherical version of -SURF_1 for Local FWHM estimates.
        clean: Strip text from output to simplify parsing.
        detrend: Detrend to order 'q'. If q is not given, the program picks\
            q=NT/30.
        detpoly: Detrend with polynomials of order p.
        detprefix: Save the detrended file into a dataset with prefix 'd'.
        prefix: Prefix of output data set.
        vox_size: Specify the nominal voxel size in mm.
        neighborhood: Neighborhood radius R for local FWHM estimates.
        ok_warn: Flag to set the mode to ok_warn.
        examples: Show command line examples and quit.
        slice_: Use the contours from planar intersections to estimate\
            gradients. For testing and development purposes only.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfFwhmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_FWHM_METADATA)
    cargs = []
    cargs.append("SurfFWHM")
    cargs.append(execution.input_file(input_file))
    if mask is not None:
        cargs.extend([
            "-MASK",
            execution.input_file(mask)
        ])
    if surf_1 is not None:
        cargs.extend([
            "-SURF_1",
            surf_1
        ])
    if surf_sphere is not None:
        cargs.extend([
            "-SURF_SPHERE",
            surf_sphere
        ])
    if clean:
        cargs.append("-clean")
    if detrend is not None:
        cargs.extend([
            "-detrend",
            str(detrend)
        ])
    if detpoly is not None:
        cargs.extend([
            "-detpoly",
            str(detpoly)
        ])
    if detprefix is not None:
        cargs.extend([
            "-detprefix",
            detprefix
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if vox_size is not None:
        cargs.extend([
            "-vox_size",
            str(vox_size)
        ])
    if neighborhood is not None:
        cargs.extend([
            "-hood",
            str(neighborhood)
        ])
    if ok_warn:
        cargs.append("-ok_warn")
    if examples:
        cargs.append("-examples")
    if slice_:
        cargs.append("-slice")
    cargs.append("[TALK_SUMA_OPTIONS]")
    cargs.append("[NIML_OPTIONS]")
    cargs.append("[DEBUG_OPTIONS]")
    cargs.append("[HELP_OPTIONS]")
    ret = SurfFwhmOutputs(
        root=execution.output_file("."),
        detrended_output=execution.output_file(prefix + ".1D.dset") if (prefix is not None) else None,
        main_output=execution.output_file(prefix + ".nii.gz") if (prefix is not None) else None,
        histogram_output=execution.output_file(prefix + "_histog.1D") if (prefix is not None) else None,
        mask_output=execution.output_file(prefix + "_mask.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_FWHM_METADATA",
    "SurfFwhmOutputs",
    "surf_fwhm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_TRANSFORM_METADATA = Metadata(
    id="6c64fbb5ab15f44e615628373fe6cb0c895c027d.boutiques",
    name="reg_transform",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegTransformOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_transform(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cpp2def_output_file: OutputPathType
    """File containing the CPP to DEF converted deformation field."""
    comp1_output_file: OutputPathType
    """File containing the composed deformation field from two control point
    lattices."""
    comp2_output_file: OutputPathType
    """File containing the composed deformation field from a deformation field
    and a control point lattice."""
    comp3_output_file: OutputPathType
    """File containing the composed deformation field from two deformation
    fields."""
    def2disp_output_file: OutputPathType
    """File containing the converted displacement field from a deformation
    field."""
    disp2def_output_file: OutputPathType
    """File containing the converted deformation field from a displacement
    field."""
    upd_sform_output_file: OutputPathType
    """File containing the updated image with modified sform."""
    aff2def_output_file: OutputPathType
    """File containing the composed deformation field from a non-rigid and an
    affine transformation."""
    inv_affine_output_file: OutputPathType
    """File containing the inverted affine matrix."""
    comp_aff_output_file: OutputPathType
    """File containing the composed affine matrix."""


def reg_transform(
    reference_image: InputPathType,
    runner: Runner | None = None,
) -> RegTransformOutputs:
    """
    Tool for performing various transformation operations on medical images
    including control point to deformation conversion, composition of
    transformations, and converting between deformation and displacement fields.
    
    Author: Marc Modat
    
    URL: https://example.com/reg_transform_docs
    
    Args:
        reference_image: Filename of the reference image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegTransformOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_TRANSFORM_METADATA)
    cargs = []
    cargs.append("reg_transform")
    cargs.append("-ref")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    cargs.append("[OPTIONS]")
    ret = RegTransformOutputs(
        root=execution.output_file("."),
        cpp2def_output_file=execution.output_file("[CPP2DEF_OUTPUT]"),
        comp1_output_file=execution.output_file("[COMP1_OUTPUT]"),
        comp2_output_file=execution.output_file("[COMP2_OUTPUT]"),
        comp3_output_file=execution.output_file("[COMP3_OUTPUT]"),
        def2disp_output_file=execution.output_file("[DEF2DISP_OUTPUT]"),
        disp2def_output_file=execution.output_file("[DISP2DEF_OUTPUT]"),
        upd_sform_output_file=execution.output_file("[UPD_SFORM_OUTPUT]"),
        aff2def_output_file=execution.output_file("[AFF2DEF_OUTPUT]"),
        inv_affine_output_file=execution.output_file("[INV_AFFINE_OUTPUT]"),
        comp_aff_output_file=execution.output_file("[COMP_AFF_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_TRANSFORM_METADATA",
    "RegTransformOutputs",
    "reg_transform",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__EXTRACT_MEICA_ORTVEC_METADATA = Metadata(
    id="9f778c740cfff0a23c70061f3c0c887ed2766f95.boutiques",
    name="@extract_meica_ortvec",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VExtractMeicaOrtvecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__extract_meica_ortvec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output 1D ortvec file"""


def v__extract_meica_ortvec(
    prefix: str,
    meica_dir: str | None = None,
    reject_ignored: int | None = None,
    reject_midk: int | None = None,
    work_dir: str | None = None,
    verbosity: str | None = None,
    runner: Runner | None = None,
) -> VExtractMeicaOrtvecOutputs:
    """
    Project good MEICA components out of bad ones.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@extract_meica_ortvec.html
    
    Args:
        prefix: Name for output 1D ortvec file.
        meica_dir: Directory for MEICA files.
        reject_ignored: Do we reject ignored components (0=keep, 1=reject),\
            default is 0.
        reject_midk: Do we reject midk components (0=keep, 1=reject), default\
            is 1.
        work_dir: Sub-directory for work.
        verbosity: Set verbosity level.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VExtractMeicaOrtvecOutputs`).
    """
    if reject_ignored is not None and not (0 <= reject_ignored <= 1): 
        raise ValueError(f"'reject_ignored' must be between 0 <= x <= 1 but was {reject_ignored}")
    if reject_midk is not None and not (0 <= reject_midk <= 1): 
        raise ValueError(f"'reject_midk' must be between 0 <= x <= 1 but was {reject_midk}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__EXTRACT_MEICA_ORTVEC_METADATA)
    cargs = []
    cargs.append("@extract_meica_ortvec")
    cargs.extend([
        "-prefix",
        prefix
    ])
    if meica_dir is not None:
        cargs.extend([
            "-meica_dir",
            meica_dir
        ])
    if reject_ignored is not None:
        cargs.extend([
            "-reject_ignored",
            str(reject_ignored)
        ])
    if reject_midk is not None:
        cargs.extend([
            "-reject_midk",
            str(reject_midk)
        ])
    if work_dir is not None:
        cargs.extend([
            "-work_dir",
            work_dir
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            verbosity
        ])
    ret = VExtractMeicaOrtvecOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(prefix + ".1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VExtractMeicaOrtvecOutputs",
    "V__EXTRACT_MEICA_ORTVEC_METADATA",
    "v__extract_meica_ortvec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__INSTALL_SURFLAYERS_DEMO1_METADATA = Metadata(
    id="96992a1608117a9aed2d18e498316b838723c21d.boutiques",
    name="@Install_SURFLAYERS_DEMO1",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VInstallSurflayersDemo1Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v__install_surflayers_demo1(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__install_surflayers_demo1(
    use_wget: bool = False,
    use_curl: bool = False,
    runner: Runner | None = None,
) -> VInstallSurflayersDemo1Outputs:
    """
    Fetches 6 driver scripts for 3 datasets as demonstrated in the 2021 OHBM poster
    and demo video about SurfLayers.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@Install_SURFLAYERS_DEMO1.html
    
    Args:
        use_wget: Use wget to download archive. Script chooses by default with\
            preference for curl.
        use_curl: Use curl to download archive. Script chooses by default with\
            preference for curl.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VInstallSurflayersDemo1Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__INSTALL_SURFLAYERS_DEMO1_METADATA)
    cargs = []
    cargs.append("@Install_SURFLAYERS_DEMO1")
    if use_wget:
        cargs.append("-wget")
    if use_curl:
        cargs.append("-curl")
    ret = VInstallSurflayersDemo1Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VInstallSurflayersDemo1Outputs",
    "V__INSTALL_SURFLAYERS_DEMO1_METADATA",
    "v__install_surflayers_demo1",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_BRAIN_SYNC_METADATA = Metadata(
    id="ba6e60b063ee8001bca1b94f5e8ff01809cb325a.boutiques",
    name="3dBrainSync",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dBrainSyncOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_brain_sync(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    qprefix_output: OutputPathType
    """Output dataset after orthogonal matrix transformation"""
    pprefix_output: OutputPathType
    """Output dataset after permutation transformation"""
    qprefix_sval: OutputPathType
    """Singular values from the BC' decomposition"""
    qprefix_qmat: OutputPathType
    """Q matrix"""
    pprefix_perm: OutputPathType
    """Permutation indexes p(i)"""


def v_3d_brain_sync(
    runner: Runner | None = None,
) -> V3dBrainSyncOutputs:
    """
    'Synchronizes' the -inset2 dataset to match the -inset1 dataset, using
    orthogonal or permutation transformation.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dBrainSync.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dBrainSyncOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_BRAIN_SYNC_METADATA)
    cargs = []
    cargs.append("3dBrainSync")
    cargs.append("[OPTIONS]")
    ret = V3dBrainSyncOutputs(
        root=execution.output_file("."),
        qprefix_output=execution.output_file("[QPREFIX].nii"),
        pprefix_output=execution.output_file("[PPREFIX].nii"),
        qprefix_sval=execution.output_file("[QPREFIX].sval.1D"),
        qprefix_qmat=execution.output_file("[QPREFIX].qmat.1D"),
        pprefix_perm=execution.output_file("[PPREFIX].perm.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dBrainSyncOutputs",
    "V_3D_BRAIN_SYNC_METADATA",
    "v_3d_brain_sync",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_MESH_METADATA = Metadata(
    id="17456ade2fbfcd3f3f36958eec099db8f2e90864.boutiques",
    name="SurfMesh",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfMeshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_mesh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface_file: OutputPathType
    """Output surface file"""


def surf_mesh(
    runner: Runner | None = None,
) -> SurfMeshOutputs:
    """
    Surface mesh manipulation tool.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/SurfMesh.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfMeshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_MESH_METADATA)
    cargs = []
    cargs.append("SurfMesh")
    cargs.append("<-i_TYPE")
    cargs.append("SURFACE>")
    cargs.append("<-o_TYPE")
    cargs.append("OUTPUT>")
    cargs.append("<-edges")
    cargs.append("FRAC>")
    cargs.append("[-sv")
    cargs.append("SURF_VOL]")
    ret = SurfMeshOutputs(
        root=execution.output_file("."),
        output_surface_file=execution.output_file("[OUTPUT].surface"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_MESH_METADATA",
    "SurfMeshOutputs",
    "surf_mesh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TBSS_4_PRESTATS_METADATA = Metadata(
    id="6d72a9e868ac4e6fa0f862c6199672dd62007438.boutiques",
    name="tbss_4_prestats",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class Tbss4PrestatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tbss_4_prestats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tbss_4_prestats(
    threshold: float = 0.2,
    runner: Runner | None = None,
) -> Tbss4PrestatsOutputs:
    """
    A tool for thresholding the Mean FA Skeleton in TBSS analysis.
    
    Author: FMRIB Software Library
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/TBSS/UserGuide
    
    Args:
        threshold: Thresholding value for the Mean FA Skeleton; recommended\
            value is 0.2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Tbss4PrestatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TBSS_4_PRESTATS_METADATA)
    cargs = []
    cargs.append("tbss_4_prestats")
    cargs.append(str(threshold))
    ret = Tbss4PrestatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TBSS_4_PRESTATS_METADATA",
    "Tbss4PrestatsOutputs",
    "tbss_4_prestats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MAKE_LABEL_TABLE_METADATA = Metadata(
    id="ba501279943e273e6d9544d2c74cff547830260c.boutiques",
    name="@MakeLabelTable",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMakeLabelTableOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__make_label_table(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_labeltable: OutputPathType
    """Output label table file"""
    output_atlas_pointlist: OutputPathType | None
    """Output atlas point list file"""
    output_csv: OutputPathType | None
    """Output CSV file from label table"""
    output_niml_atlas: OutputPathType | None
    """Output NIML file after atlasizing labeled dataset"""


def v__make_label_table(
    labeltable: str,
    atlas_pointlist: str | None = None,
    lab_r: list[str] | None = None,
    lab_v: list[str] | None = None,
    lab_file: list[str] | None = None,
    dset: InputPathType | None = None,
    longnames: float | None = None,
    last_longname_col: float | None = None,
    centers: bool = False,
    centertype: str | None = None,
    centermask: str | None = None,
    skip_novoxels: bool = False,
    all_labels: bool = False,
    all_keys: bool = False,
    lkeys: str | None = None,
    rkeys: str | None = None,
    klabel: str | None = None,
    match_label: str | None = None,
    labeltable_of_dset: InputPathType | None = None,
    word_label_match: bool = False,
    quiet_death: bool = False,
    lt_to_atlas_pl: str | None = None,
    dset_lt_to_atlas_pl: list[InputPathType] | None = None,
    lt_to_csv: InputPathType | None = None,
    atlasize_labeled_dset: InputPathType | None = None,
    atlas_file: str | None = None,
    atlas_name: str | None = None,
    atlas_description: str | None = None,
    replace: bool = False,
    add_atlas_dset: InputPathType | None = None,
    h_web: bool = False,
    h_view: bool = False,
    all_opts: bool = False,
    h_find: str | None = None,
    runner: Runner | None = None,
) -> VMakeLabelTableOutputs:
    """
    Script used to create, modify, and transform label tables.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@MakeLabelTable.html
    
    Args:
        labeltable: Name of output label table.
        atlas_pointlist: Instead of a label table, produce an atlas point list.
        lab_r: Define a label with its minimum and maximum key values.
        lab_v: Define a label and its value.
        lab_file: Specify labels and keys from a text file.
        dset: Attach the label table (or atlas point list) to dataset.
        longnames: Allow for another column of long names for regions.
        last_longname_col: Limit long names to nth column.
        centers: Compute center of mass location for each ROI.
        centertype: Different ways to compute centers (Icent, Dcent, cm).
        centermask: Calculate center of mass locations using a subset of voxels.
        skip_novoxels: Skip regions without voxels.
        all_labels: Return a listing of all labels.
        all_keys: Return a listing of all keys.
        lkeys: Return the keys whose labels match a given label.
        rkeys: Return the range (min max) of keys whose labels match a given\
            label.
        klabel: Return the label associated with a given key.
        match_label: Return labels matching a given label.
        labeltable_of_dset: Dump the labeltable from a dataset.
        word_label_match: Use word matching for labels.
        quiet_death: Do not give error messages when failing.
        lt_to_atlas_pl: Transform Label Table to Atlas Point List.
        dset_lt_to_atlas_pl: Get Label Table in dataset and write as an Atlas\
            Point List.
        lt_to_csv: Transform Label Table to CSV format.
        atlasize_labeled_dset: Transform a labeled ROI dataset into an atlas.
        atlas_file: Specify the name of the NIML file where atlas attributes\
            are stored.
        atlas_name: Name of the Atlas.
        atlas_description: Description of the Atlas, which appears in AFNI's\
            whereami window.
        replace: Replace existing Atlas if the name already exists in the NIML\
            file.
        add_atlas_dset: Add an existing atlas to an atlas file.
        h_web: Open webpage with help for this program.
        h_view: Open -help output in a GUI editor.
        all_opts: List all of the options for this script.
        h_find: Search for lines containing a specific word in the help output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMakeLabelTableOutputs`).
    """
    if lab_file is not None and not (1 <= len(lab_file) <= 2): 
        raise ValueError(f"Length of 'lab_file' must be between 1 and 2 but was {len(lab_file)}")
    if dset_lt_to_atlas_pl is not None and (len(dset_lt_to_atlas_pl) != 2): 
        raise ValueError(f"Length of 'dset_lt_to_atlas_pl' must be 2 but was {len(dset_lt_to_atlas_pl)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MAKE_LABEL_TABLE_METADATA)
    cargs = []
    cargs.append("@MakeLabelTable")
    cargs.extend([
        "-labeltable",
        labeltable
    ])
    if atlas_pointlist is not None:
        cargs.extend([
            "-atlas_pointlist",
            atlas_pointlist
        ])
    if lab_r is not None:
        cargs.extend([
            "-lab_r",
            *lab_r
        ])
    if lab_v is not None:
        cargs.extend([
            "-lab_v",
            *lab_v
        ])
    if lab_file is not None:
        cargs.extend([
            "-lab_file",
            *lab_file
        ])
    if dset is not None:
        cargs.extend([
            "-dset",
            execution.input_file(dset)
        ])
    if longnames is not None:
        cargs.extend([
            "-longnames",
            str(longnames)
        ])
    if last_longname_col is not None:
        cargs.extend([
            "-last_longname_col",
            str(last_longname_col)
        ])
    if centers:
        cargs.append("-centers")
    if centertype is not None:
        cargs.extend([
            "-centertype",
            centertype
        ])
    if centermask is not None:
        cargs.extend([
            "-centermask",
            centermask
        ])
    if skip_novoxels:
        cargs.append("-skip_novoxels")
    if all_labels:
        cargs.append("-all_labels")
    if all_keys:
        cargs.append("-all_keys")
    if lkeys is not None:
        cargs.extend([
            "-lkeys",
            lkeys
        ])
    if rkeys is not None:
        cargs.extend([
            "-rkeys",
            rkeys
        ])
    if klabel is not None:
        cargs.extend([
            "-klabel",
            klabel
        ])
    if match_label is not None:
        cargs.extend([
            "-match_label",
            match_label
        ])
    if labeltable_of_dset is not None:
        cargs.extend([
            "-labeltable_of_dset",
            execution.input_file(labeltable_of_dset)
        ])
    if word_label_match:
        cargs.append("-word_label_match")
    if quiet_death:
        cargs.append("-quiet_death")
    if lt_to_atlas_pl is not None:
        cargs.extend([
            "-LT_to_atlas_PL",
            lt_to_atlas_pl
        ])
    if dset_lt_to_atlas_pl is not None:
        cargs.extend([
            "-dset_LT_to_atlas_PL",
            *[execution.input_file(f) for f in dset_lt_to_atlas_pl]
        ])
    if lt_to_csv is not None:
        cargs.extend([
            "-LT_to_CSV",
            execution.input_file(lt_to_csv)
        ])
    if atlasize_labeled_dset is not None:
        cargs.extend([
            "-atlasize_labeled_dset",
            execution.input_file(atlasize_labeled_dset)
        ])
    if atlas_file is not None:
        cargs.extend([
            "-atlas_file",
            atlas_file
        ])
    if atlas_name is not None:
        cargs.extend([
            "-atlas_name",
            atlas_name
        ])
    if atlas_description is not None:
        cargs.extend([
            "-atlas_description",
            atlas_description
        ])
    if replace:
        cargs.append("-replace")
    if add_atlas_dset is not None:
        cargs.extend([
            "-add_atlas_dset",
            execution.input_file(add_atlas_dset)
        ])
    if h_web:
        cargs.append("-h_web")
    if h_view:
        cargs.append("-h_view")
    if all_opts:
        cargs.append("-all_opts")
    if h_find is not None:
        cargs.extend([
            "-h_find",
            h_find
        ])
    ret = VMakeLabelTableOutputs(
        root=execution.output_file("."),
        output_labeltable=execution.output_file(labeltable + ".niml.lt"),
        output_atlas_pointlist=execution.output_file(atlas_pointlist + ".niml.atlas") if (atlas_pointlist is not None) else None,
        output_csv=execution.output_file(pathlib.Path(lt_to_csv).name + ".csv") if (lt_to_csv is not None) else None,
        output_niml_atlas=execution.output_file(pathlib.Path(atlasize_labeled_dset).name + ".niml") if (atlasize_labeled_dset is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMakeLabelTableOutputs",
    "V__MAKE_LABEL_TABLE_METADATA",
    "v__make_label_table",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MIST_DISPLAY_METADATA = Metadata(
    id="a3dfab2cb8ff840618615f7b6468256b6544fad3.boutiques",
    name="mist_display",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class MistDisplayOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mist_display(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mist_display(
    mode: typing.Literal["simple", "pvals", "noscalars"],
    help_: bool = False,
    runner: Runner | None = None,
) -> MistDisplayOutputs:
    """
    Tool to show scalars on mesh.
    
    Author: Unknown
    
    Args:
        mode: Mode for displaying scalars on mesh.
        help_: Show help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MistDisplayOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MIST_DISPLAY_METADATA)
    cargs = []
    cargs.append("mist_display")
    cargs.append(mode)
    if help_:
        cargs.append("--help")
    ret = MistDisplayOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MIST_DISPLAY_METADATA",
    "MistDisplayOutputs",
    "mist_display",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIRDESIGN_METADATA = Metadata(
    id="f49bb30a7acca5ca76111edd30083bdff49133e5.boutiques",
    name="FIRdesign",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FirdesignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `firdesign(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def firdesign(
    fbot: float,
    ftop: float,
    ntap: float,
    runner: Runner | None = None,
) -> FirdesignOutputs:
    """
    Uses the Remez algorithm to calculate the FIR filter weights for a bandpass
    filter; results are written to stdout in an unadorned (no header) column of
    numbers.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/FIRdesign.html
    
    Args:
        fbot: Lowest frequency in the pass band.
        ftop: Highest frequency in the pass band, must be higher than fbot and\
            <= 0.5/TR.
        ntap: Number of filter weights (AKA 'taps') to use, must be in the\
            range 8..2000 (inclusive).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FirdesignOutputs`).
    """
    if not (0 <= fbot): 
        raise ValueError(f"'fbot' must be greater than 0 <= x but was {fbot}")
    if not (0 <= ftop): 
        raise ValueError(f"'ftop' must be greater than 0 <= x but was {ftop}")
    if not (8 <= ntap <= 2000): 
        raise ValueError(f"'ntap' must be between 8 <= x <= 2000 but was {ntap}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIRDESIGN_METADATA)
    cargs = []
    cargs.append("FIRdesign")
    cargs.append("[OPTIONS]")
    cargs.append(str(fbot))
    cargs.append(str(ftop))
    cargs.append(str(ntap))
    ret = FirdesignOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIRDESIGN_METADATA",
    "FirdesignOutputs",
    "firdesign",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GET_AFNI_VIEW_METADATA = Metadata(
    id="4292a6b6f888f770d08953380d9fb8548bf04018.boutiques",
    name="@GetAfniView",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGetAfniViewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__get_afni_view(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    afni_view: OutputPathType
    """The AFNI view extension retrieved from the dataset name"""


def v__get_afni_view(
    dataset_name: str,
    runner: Runner | None = None,
) -> VGetAfniViewOutputs:
    """
    A tool to retrieve the AFNI view of a given dataset name.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@GetAfniView.html
    
    Args:
        dataset_name: Name of the dataset (including path) from which to\
            retrieve the AFNI view (+orig, +acpc, etc.).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGetAfniViewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GET_AFNI_VIEW_METADATA)
    cargs = []
    cargs.append("@GetAfniView")
    cargs.append(dataset_name)
    ret = VGetAfniViewOutputs(
        root=execution.output_file("."),
        afni_view=execution.output_file("view_extension.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGetAfniViewOutputs",
    "V__GET_AFNI_VIEW_METADATA",
    "v__get_afni_view",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANNOTATION_RESAMPLE_METADATA = Metadata(
    id="97a1012c1e236672dd4a3e38c6d31fbee2a10f0f.boutiques",
    name="annotation-resample",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class AnnotationResampleSurfacePair:
    """
    pair of surfaces for resampling surface annotations for one structure.
    """
    source_surface: InputPathType
    """the midthickness surface of the current mesh the annotations use"""
    target_surface: InputPathType
    """the midthickness surface of the mesh the annotations should be
    transferred to"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-surface-pair")
        cargs.append(execution.input_file(self.source_surface))
        cargs.append(execution.input_file(self.target_surface))
        return cargs


class AnnotationResampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `annotation_resample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def annotation_resample(
    annotation_in: InputPathType,
    annotation_out: str,
    surface_pair: list[AnnotationResampleSurfacePair] | None = None,
    runner: Runner | None = None,
) -> AnnotationResampleOutputs:
    """
    Resample an annotation file to different meshes.
    
    Resample an annotation file from the source mesh to the target mesh.
    
    Only annotations in surface space are modified, no changes are made to
    annotations in other spaces. The -surface-pair option may be repeated for
    additional structures used by surface space annotations.
    
    Author: Washington University School of Medicin
    
    Args:
        annotation_in: the annotation file to resample.
        annotation_out: name of resampled annotation file.
        surface_pair: pair of surfaces for resampling surface annotations for\
            one structure.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnnotationResampleOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANNOTATION_RESAMPLE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-annotation-resample")
    cargs.append(execution.input_file(annotation_in))
    cargs.append(annotation_out)
    if surface_pair is not None:
        cargs.extend([a for c in [s.run(execution) for s in surface_pair] for a in c])
    ret = AnnotationResampleOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANNOTATION_RESAMPLE_METADATA",
    "AnnotationResampleOutputs",
    "AnnotationResampleSurfacePair",
    "annotation_resample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_MEPFM_METADATA = Metadata(
    id="d7d16947a2045612b84972ca23df8747949155b1.boutiques",
    name="3dMEPFM",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dMepfmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_mepfm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dr2_output: OutputPathType
    """Changes in R2* parameter, assumed to represent neuronal-related signal
    changes"""
    dr2fit_output: OutputPathType
    """Convolution of DR2 with HRF, one volume per echo"""
    ds0_output: OutputPathType
    """Changes in net magnetization (S0) (if estimated)"""
    lambda_output: OutputPathType
    """Regularization parameter"""
    sigmas_mad_output: OutputPathType
    """Estimate of the noise standard deviation after wavelet decomposition for
    each input dataset"""
    costs_output: OutputPathType
    """Cost function to select the regularization parameter (lambda) according
    to selection criterion"""


def v_3d_mepfm(
    input_files: list[str],
    dbg_args: bool = False,
    mask: InputPathType | None = None,
    hrf_model: str | None = None,
    verbosity: int | None = None,
    runner: Runner | None = None,
) -> V3dMepfmOutputs:
    """
    Voxelwise deconvolution of Multiecho fMRI data to yield time-varying estimates
    of changes in transverse relaxation (DR2*) and optionally, net magnetization
    (DS0).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dMEPFM.html
    
    Args:
        input_files: Dataset to analyze with Multiecho Paradigm Free Mapping,\
            along with the echo time.
        dbg_args: Enable R to save the parameters in .3dMEPFM.dbg.AFNI.args in\
            the current directory.
        mask: Process voxels inside this mask only. Default is no masking.
        hrf_model: Haemodynamic response function used for deconvolution.
        verbosity: Verbosity level. 0 for quiet, 1 (default) or more:\
            talkative.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dMepfmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_MEPFM_METADATA)
    cargs = []
    cargs.append("3dMEPFM")
    cargs.extend([
        "-input",
        *input_files
    ])
    if dbg_args:
        cargs.append("-dbgArgs")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if hrf_model is not None:
        cargs.extend([
            "-hrf",
            hrf_model
        ])
    if verbosity is not None:
        cargs.extend([
            "-verb",
            str(verbosity)
        ])
    cargs.append("[OTHER_OPTIONS]")
    ret = V3dMepfmOutputs(
        root=execution.output_file("."),
        dr2_output=execution.output_file("DR2_[PREFIX]_*.nii.gz"),
        dr2fit_output=execution.output_file("DR2fit_[PREFIX]_*.nii.gz"),
        ds0_output=execution.output_file("DS0_[PREFIX]_*.nii.gz"),
        lambda_output=execution.output_file("lambda_[PREFIX]_*.nii.gz"),
        sigmas_mad_output=execution.output_file("sigmas_MAD_[PREFIX]_*.nii.gz"),
        costs_output=execution.output_file("costs_[PREFIX]_*.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dMepfmOutputs",
    "V_3D_MEPFM_METADATA",
    "v_3d_mepfm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_UPSAMPLE_METADATA = Metadata(
    id="bacdcc37f2395a4c7001b1977887b1d356a36a4a.boutiques",
    name="3dUpsample",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dUpsampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_upsample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType | None
    """Upsampled dataset in BRIK format."""
    output_head: OutputPathType | None
    """Header information for the upsampled dataset."""


def v_3d_upsample(
    upsample_factor: int,
    input_dataset: str,
    linear_interpolation: bool = False,
    output_prefix: str | None = None,
    verbose_flag: bool = False,
    datatype: str | None = None,
    runner: Runner | None = None,
) -> V3dUpsampleOutputs:
    """
    Upsamples a 3D+time dataset in the time direction by a specified factor.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/3dUpsample.html
    
    Args:
        upsample_factor: Upsampling factor; must be between 2 and 320\
            (inclusive).
        input_dataset: Input dataset.
        linear_interpolation: Use linear interpolation instead of 7th order\
            polynomial interpolation.
        output_prefix: Define the prefix name of the output dataset; default is\
            'Upsam'.
        verbose_flag: Print verbose output.
        datatype: Specify the datatype for the output dataset (float, short,\
            byte); default is float.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dUpsampleOutputs`).
    """
    if not (2 <= upsample_factor <= 320): 
        raise ValueError(f"'upsample_factor' must be between 2 <= x <= 320 but was {upsample_factor}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_UPSAMPLE_METADATA)
    cargs = []
    cargs.append("3dUpsample")
    cargs.extend([
        "-n",
        str(upsample_factor)
    ])
    cargs.extend([
        "-input",
        input_dataset
    ])
    if linear_interpolation:
        cargs.append("-1")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if verbose_flag:
        cargs.append("-verb")
    if datatype is not None:
        cargs.extend([
            "-datum",
            datatype
        ])
    ret = V3dUpsampleOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file(output_prefix + "+orig.BRIK") if (output_prefix is not None) else None,
        output_head=execution.output_file(output_prefix + "+orig.HEAD") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dUpsampleOutputs",
    "V_3D_UPSAMPLE_METADATA",
    "v_3d_upsample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__DIFF_FILES_METADATA = Metadata(
    id="06448df7b458fee6cb35a742b2693373b6f580ad.boutiques",
    name="@diff.files",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VDiffFilesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__diff_files(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__diff_files(
    files: list[str],
    old_dir: str,
    runner: Runner | None = None,
) -> VDiffFilesOutputs:
    """
    Show file differences (between specified files and those in another directory).
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/@diff.files.html
    
    Args:
        files: List of files to compare.
        old_dir: Directory containing the files to compare against.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VDiffFilesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__DIFF_FILES_METADATA)
    cargs = []
    cargs.append("@diff.files")
    cargs.append("[OPTIONS]")
    cargs.extend(files)
    cargs.append(old_dir)
    ret = VDiffFilesOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VDiffFilesOutputs",
    "V__DIFF_FILES_METADATA",
    "v__diff_files",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_UPSAMPLE_METADATA = Metadata(
    id="994f90098f887f5f9885ca987566d2c77365ab7e.boutiques",
    name="1dUpsample",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dUpsampleOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_upsample(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Upsampled 1D time series output"""


def v_1d_upsample(
    upsample_factor: float,
    input_file: InputPathType,
    linear_interpolation: bool = False,
    runner: Runner | None = None,
) -> V1dUpsampleOutputs:
    """
    Upsamples a 1D time series to a finer time grid.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/1dUpsample.html
    
    Args:
        upsample_factor: Upsample factor (integer from 2..32).
        input_file: Input 1D time series file.
        linear_interpolation: Use 1st order polynomials (i.e., linear\
            interpolation) instead of 7th order polynomials.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dUpsampleOutputs`).
    """
    if not (2 <= upsample_factor <= 32): 
        raise ValueError(f"'upsample_factor' must be between 2 <= x <= 32 but was {upsample_factor}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_UPSAMPLE_METADATA)
    cargs = []
    cargs.append("1dUpsample")
    cargs.append(str(upsample_factor))
    cargs.append(execution.input_file(input_file))
    if linear_interpolation:
        cargs.append("-one")
    ret = V1dUpsampleOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file("ethel.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dUpsampleOutputs",
    "V_1D_UPSAMPLE_METADATA",
    "v_1d_upsample",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_PARCEL_RESAMPLING_METADATA = Metadata(
    id="3a64f15234617b08fd43ca4d964fd2b1aa355b36.boutiques",
    name="volume-parcel-resampling",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class VolumeParcelResamplingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_parcel_resampling(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    volume_out: OutputPathType
    """output volume"""


def volume_parcel_resampling(
    volume_in: InputPathType,
    cur_parcels: InputPathType,
    new_parcels: InputPathType,
    kernel: float,
    volume_out: str,
    opt_fix_zeros: bool = False,
    opt_fwhm: bool = False,
    opt_subvolume_subvol: str | None = None,
    runner: Runner | None = None,
) -> VolumeParcelResamplingOutputs:
    """
    Smooth and resample volume parcels.
    
    Smooths and resamples the region inside each label in cur-parcels to the
    region of the same label name in new-parcels. Any voxels in the output label
    region but outside the input label region will be extrapolated from nearby
    data. The -fix-zeros option causes the smoothing to not use an input value
    if it is zero, but still write a smoothed value to the voxel, and after
    smoothing is complete, it will check for any remaining values of zero, and
    fill them in with extrapolated values.
    
    Note: all volumes must have the same dimensions and spacing. To use a
    different output space, see -volume-parcel-resampling-generic.
    
    Author: Washington University School of Medicin
    
    Args:
        volume_in: the input data volume.
        cur_parcels: label volume of where the parcels currently are.
        new_parcels: label volume of where the parcels should be.
        kernel: gaussian kernel size in mm to smooth by during resampling, as\
            sigma by default.
        volume_out: output volume.
        opt_fix_zeros: treat zero values as not being data.
        opt_fwhm: smoothing kernel size is FWHM, not sigma.
        opt_subvolume_subvol: select a single subvolume as input: the subvolume\
            number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeParcelResamplingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_PARCEL_RESAMPLING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-parcel-resampling")
    cargs.append(execution.input_file(volume_in))
    cargs.append(execution.input_file(cur_parcels))
    cargs.append(execution.input_file(new_parcels))
    cargs.append(str(kernel))
    cargs.append(volume_out)
    if opt_fix_zeros:
        cargs.append("-fix-zeros")
    if opt_fwhm:
        cargs.append("-fwhm")
    if opt_subvolume_subvol is not None:
        cargs.extend([
            "-subvolume",
            opt_subvolume_subvol
        ])
    ret = VolumeParcelResamplingOutputs(
        root=execution.output_file("."),
        volume_out=execution.output_file(volume_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_PARCEL_RESAMPLING_METADATA",
    "VolumeParcelResamplingOutputs",
    "volume_parcel_resampling",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUICKSPEC_METADATA = Metadata(
    id="0d0a4691610cda068a2617e4fa5f9bb9a5df5d19.boutiques",
    name="quickspec",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QuickspecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quickspec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_specfile: OutputPathType
    """The spec file output."""


def quickspec(
    runner: Runner | None = None,
) -> QuickspecOutputs:
    """
    A quick and dirty way of loading a surface into SUMA or command line programs
    using a spec file.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/quickspec.html
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuickspecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUICKSPEC_METADATA)
    cargs = []
    cargs.append("quickspec")
    cargs.append("[PARAMS...]")
    ret = QuickspecOutputs(
        root=execution.output_file("."),
        out_specfile=execution.output_file("[SPECFILE]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUICKSPEC_METADATA",
    "QuickspecOutputs",
    "quickspec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__AFNI_REFACER_MAKE_MASTER_ADDENDUM_METADATA = Metadata(
    id="bbef26b5a7cdd07e55ed085eb8d5d0eddc215a86.boutiques",
    name="@afni_refacer_make_master_addendum",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAfniRefacerMakeMasterAddendumOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__afni_refacer_make_master_addendum(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__afni_refacer_make_master_addendum(
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> VAfniRefacerMakeMasterAddendumOutputs:
    """
    Adjunct program for AFNI refacer, takes no command line arguments.
    
    Author: AFNI Team
    
    URL:
    https://afni.nimh.nih.gov/pub/dist/doc/program_help/@afni_refacer_make_master_addendum.html
    
    Args:
        help_: Display the help message.
        version: Display the version info.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAfniRefacerMakeMasterAddendumOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__AFNI_REFACER_MAKE_MASTER_ADDENDUM_METADATA)
    cargs = []
    cargs.append("afni_refacer_make_master_addendum")
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-ver")
    ret = VAfniRefacerMakeMasterAddendumOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAfniRefacerMakeMasterAddendumOutputs",
    "V__AFNI_REFACER_MAKE_MASTER_ADDENDUM_METADATA",
    "v__afni_refacer_make_master_addendum",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_CHECK_OMP_METADATA = Metadata(
    id="5590758fc8874a83053de43d314f6e090fd6b815.boutiques",
    name="afni_check_omp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniCheckOmpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_check_omp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_check_omp(
    iterations: float | None = None,
    runner: Runner | None = None,
) -> AfniCheckOmpOutputs:
    """
    Tool to check the OpenMP multi-threading environment for AFNI.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/afni_check_omp.html
    
    Args:
        iterations: Number of iterations to run.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniCheckOmpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_CHECK_OMP_METADATA)
    cargs = []
    cargs.append("afni_check_omp")
    if iterations is not None:
        cargs.append(str(iterations))
    ret = AfniCheckOmpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_CHECK_OMP_METADATA",
    "AfniCheckOmpOutputs",
    "afni_check_omp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FIM2_METADATA = Metadata(
    id="4bbd219be584e7d98899e024cecb64199f510e68.boutiques",
    name="fim2",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Fim2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `fim2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    activation_magnitudes: OutputPathType
    """Activation magnitudes output file"""
    correlation_image: OutputPathType
    """Correlation image output file"""
    contrast_to_noise_image: OutputPathType
    """Contrast-to-noise image output file"""
    std_deviation_image: OutputPathType
    """Standard deviation image output file"""
    ls_fit_coefficients: OutputPathType
    """Least squares fit coefficients image files"""
    subtracted_references: OutputPathType
    """Subtracted ortho reference time series images"""


def fim2(
    image_files: list[InputPathType],
    runner: Runner | None = None,
) -> Fim2Outputs:
    """
    Functional Imaging Mapping Tool.
    
    Author: AFNI Team
    
    URL: https://afni.nimh.nih.gov/pub/dist/doc/program_help/fim2.html
    
    Args:
        image_files: Input MRI image files.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fim2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FIM2_METADATA)
    cargs = []
    cargs.append("fim2")
    cargs.append("[OPTIONS]")
    cargs.extend([execution.input_file(f) for f in image_files])
    ret = Fim2Outputs(
        root=execution.output_file("."),
        activation_magnitudes=execution.output_file("[FIMFILE]"),
        correlation_image=execution.output_file("[CORFILE]"),
        contrast_to_noise_image=execution.output_file("[CNRFILE]"),
        std_deviation_image=execution.output_file("[SIGFILE]"),
        ls_fit_coefficients=execution.output_file("[FITFILE]"),
        subtracted_references=execution.output_file("[SUBORT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FIM2_METADATA",
    "Fim2Outputs",
    "fim2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

POSSUM_MATRIX_METADATA = Metadata(
    id="56cc1f935af40890ed7af2d0f4171e791e0df5cb.boutiques",
    name="possum_matrix",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class PossumMatrixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `possum_matrix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_main_matrix: OutputPathType
    """Main event matrix output file"""


def possum_matrix(
    pulse_sequence: str,
    motion_matrix: str,
    output_matrix: str,
    verbose_flag: bool = False,
    help_flag: bool = False,
    old_version_flag: bool = False,
    segment_size: float | None = None,
    runner: Runner | None = None,
) -> PossumMatrixOutputs:
    """
    Event matrix generator for POSSUM simulation in FSL.
    
    Author: University of Oxford (Ivana Drobnjak)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/POSSUM
    
    Args:
        pulse_sequence: Pulse sequence - all additional files with extensions\
            .posx, .posy, etc., expected to be in the same directory.
        motion_matrix: Motion matrix [time(s) Tx(m) Ty(m) Tz(m) Rx(rad) Ry(rad)\
            Rz(rad)].
        output_matrix: Main event matrix [t(s), rf_ang(rad), rf_freq_band(Hz),\
            (4)=rf_cent_freq(Hz), read(1/0), Gx, Gy, Gz(T/m), Tx, Ty, Tz(m),\
            angle_of_rot B(rad), rot_axis Bx, By, Bz(m), angle_of_rot A(rad),\
            rot_axis Ax, Ay, Az(m)].
        verbose_flag: Switch on diagnostic messages.
        help_flag: Display this help message.
        old_version_flag: Allows for the old version of the sorter to run.
        segment_size: Setting the size of the segment of the matrix that is\
            read in one at a time.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `PossumMatrixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(POSSUM_MATRIX_METADATA)
    cargs = []
    cargs.append("possum_matrix")
    cargs.append("-p")
    cargs.extend([
        "-p",
        pulse_sequence
    ])
    cargs.append("-m")
    cargs.extend([
        "-m",
        motion_matrix
    ])
    cargs.append("-o")
    cargs.extend([
        "-o",
        output_matrix
    ])
    if verbose_flag:
        cargs.append("-v")
    if help_flag:
        cargs.append("-h")
    if old_version_flag:
        cargs.append("--old")
    if segment_size is not None:
        cargs.extend([
            "--seg",
            str(segment_size)
        ])
    ret = PossumMatrixOutputs(
        root=execution.output_file("."),
        output_main_matrix=execution.output_file(output_matrix),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "POSSUM_MATRIX_METADATA",
    "PossumMatrixOutputs",
    "possum_matrix",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HALFCOSBASIS_METADATA = Metadata(
    id="dd4f8ba7f704df6d44cb6defab93127cf525dbd0.boutiques",
    name="halfcosbasis",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class HalfcosbasisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `halfcosbasis(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def halfcosbasis(
    hrf_param_file_hf: InputPathType,
    verbose_flag: bool = False,
    debug_level_debuglevel: float | None = None,
    timing_on_flag: bool = False,
    log_dir_logdir: str | None = None,
    num_hrf_samples: float | None = 1000,
    num_hrf_basis_funcs: float | None = 3,
    num_secs_nsecs: float | None = 40,
    temp_res: float | None = 0.05,
    runner: Runner | None = None,
) -> HalfcosbasisOutputs:
    """
    Tool for handling half-cosine basis functions in FSL.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
    
    Args:
        hrf_param_file_hf: Half cosine HRF parameter ranges file.
        verbose_flag: Switch on diagnostic messages.
        debug_level_debuglevel: Set debug level.
        timing_on_flag: Turn timing on.
        log_dir_logdir: Log directory.
        num_hrf_samples: Number of HRF samples to use (default is 1000).
        num_hrf_basis_funcs: Number of HRF basis functions to use (default is\
            3).
        num_secs_nsecs: Number of seconds (default is 40).
        temp_res: Temporal resolution (default is 0.05).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HalfcosbasisOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HALFCOSBASIS_METADATA)
    cargs = []
    cargs.append("halfcosbasis")
    cargs.extend([
        "--hf",
        execution.input_file(hrf_param_file_hf)
    ])
    if verbose_flag:
        cargs.append("-V")
    if debug_level_debuglevel is not None:
        cargs.extend([
            "--debuglevel",
            str(debug_level_debuglevel)
        ])
    if timing_on_flag:
        cargs.append("--to")
    if log_dir_logdir is not None:
        cargs.extend([
            "--logdir",
            log_dir_logdir
        ])
    if num_hrf_samples is not None:
        cargs.extend([
            "--nhs",
            str(num_hrf_samples)
        ])
    if num_hrf_basis_funcs is not None:
        cargs.extend([
            "--nbfs",
            str(num_hrf_basis_funcs)
        ])
    if num_secs_nsecs is not None:
        cargs.extend([
            "--nsecs",
            str(num_secs_nsecs)
        ])
    if temp_res is not None:
        cargs.extend([
            "--res",
            str(temp_res)
        ])
    ret = HalfcosbasisOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HALFCOSBASIS_METADATA",
    "HalfcosbasisOutputs",
    "halfcosbasis",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAST_METADATA = Metadata(
    id="d94fbd811651e9f62d28694534e7db875d113d45.boutiques",
    name="fast",
    package="fsl",
    container_image_tag="mcin/fsl:6.0.5",
)


class FastOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fast(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mixeltype: OutputPathType | None
    """Path/name of mixeltype volume file _mixeltype."""
    bias_field: OutputPathType | None
    """No description provided."""
    partial_volume_files: OutputPathType | None
    """No description provided."""
    partial_volume_map: OutputPathType | None
    """Path/name of partial volume file _pveseg."""
    restored_image: OutputPathType | None
    """No description provided."""
    tissue_class_map: OutputPathType | None
    """Path/name of binary segmented volume file one val for each class _seg."""


def fast(
    in_files: list[InputPathType],
    number_classes: int | None = None,
    bias_iters: int | None = None,
    bias_lowpass: float | None = None,
    img_type: typing.Literal[1, 2, 3] | None = None,
    init_seg_smooth: float | None = None,
    segments: bool = False,
    init_transform: InputPathType | None = None,
    other_priors: list[InputPathType] | None = None,
    output_biasfield: bool = False,
    output_biascorrected: bool = False,
    no_bias: bool = False,
    channels: int | None = None,
    out_basename: str | None = "fast_out",
    use_priors: bool = False,
    no_pve: bool = False,
    segment_iters: int | None = None,
    mixel_smooth: float | None = None,
    hyper: float | None = None,
    verbose: bool = False,
    manual_seg: InputPathType | None = None,
    iters_afterbias: int | None = None,
    runner: Runner | None = None,
) -> FastOutputs:
    """
    FAST (FMRIB's Automated Segmentation Tool) segments a 3D image of the brain into
    different tissue types (Grey Matter, White Matter, CSF, etc.), whilst also
    correcting for spatial intensity variations (also known as bias field or RF
    inhomogeneities). The underlying method is based on a hidden Markov random field
    model and an associated Expectation-Maximization algorithm. The whole process is
    fully automated and can also produce a bias field-corrected input image and a
    probabilistic and/or partial volume tissue segmentation. It is robust and
    reliable, compared to most finite mixture model-based methods, which are
    sensitive to noise.
    
    Author: Oxford Centre for Functional MRI of the Brain (FMRIB)
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FAST
    
    Args:
        in_files: Image, or multi-channel set of images, to be segmented.
        number_classes: number of tissue-type classes; default=3.
        bias_iters: number of main-loop iterations during bias-field removal;\
            default=4.
        bias_lowpass: bias field smoothing extent (FWHM) in mm; default=20.
        img_type: type of image 1=T1, 2=T2, 3=PD; default=T1.
        init_seg_smooth: initial segmentation spatial smoothness (during bias\
            field estimation); default=0.02.
        segments: outputs a separate binary image for each tissue type.
        init_transform: initialise using priors; you must supply a FLIRT\
            transform.
        other_priors: Alternative prior images.
        output_biasfield: Output estimated bias field.
        output_biascorrected: Output restored image (bias-corrected image).
        no_bias: Do not remove bias field.
        channels: number of input images (channels); default 1.
        out_basename: Base name of output files.
        use_priors: Use priors throughout.
        no_pve: Turn off pve (partial volume estimation).
        segment_iters: number of segmentation-initialisation iterations;\
            default=15.
        mixel_smooth: spatial smoothness for mixeltype; default=0.3.
        hyper: 0.0 <= a floating point number <= 1.0. segmentation spatial\
            smoothness; default=0.1.
        verbose: Switch on diagnostic messages.
        manual_seg: Filename containing intensities.
        iters_afterbias: number of main-loop iterations after bias-field\
            removal; default=4.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FastOutputs`).
    """
    if number_classes is not None and not (1 <= number_classes): 
        raise ValueError(f"'number_classes' must be greater than 1 <= x but was {number_classes}")
    if bias_iters is not None and not (1 <= bias_iters): 
        raise ValueError(f"'bias_iters' must be greater than 1 <= x but was {bias_iters}")
    if bias_lowpass is not None and not (0 <= bias_lowpass): 
        raise ValueError(f"'bias_lowpass' must be greater than 0 <= x but was {bias_lowpass}")
    if segment_iters is not None and not (1 <= segment_iters): 
        raise ValueError(f"'segment_iters' must be greater than 1 <= x but was {segment_iters}")
    if hyper is not None and not (0.0 <= hyper <= 1.0): 
        raise ValueError(f"'hyper' must be between 0.0 <= x <= 1.0 but was {hyper}")
    if iters_afterbias is not None and not (1 <= iters_afterbias): 
        raise ValueError(f"'iters_afterbias' must be greater than 1 <= x but was {iters_afterbias}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAST_METADATA)
    cargs = []
    cargs.append("fast")
    if number_classes is not None:
        cargs.extend([
            "-n",
            str(number_classes)
        ])
    if bias_iters is not None:
        cargs.extend([
            "-I",
            str(bias_iters)
        ])
    if bias_lowpass is not None:
        cargs.extend([
            "-l",
            str(bias_lowpass)
        ])
    if img_type is not None:
        cargs.extend([
            "-t",
            str(img_type)
        ])
    if init_seg_smooth is not None:
        cargs.extend([
            "-f",
            str(init_seg_smooth)
        ])
    if segments:
        cargs.append("-g")
    if init_transform is not None:
        cargs.extend([
            "-a",
            execution.input_file(init_transform)
        ])
    if other_priors is not None:
        cargs.extend([
            "-A",
            *[execution.input_file(f) for f in other_priors]
        ])
    if output_biasfield:
        cargs.append("-b")
    if output_biascorrected:
        cargs.append("-B")
    if no_bias:
        cargs.append("-N")
    if channels is not None:
        cargs.extend([
            "-S",
            str(channels)
        ])
    if out_basename is not None:
        cargs.extend([
            "-o",
            out_basename
        ])
    if use_priors:
        cargs.append("-P")
    if no_pve:
        cargs.append("--nopve")
    if segment_iters is not None:
        cargs.extend([
            "-W",
            str(segment_iters)
        ])
    if mixel_smooth is not None:
        cargs.extend([
            "-R",
            str(mixel_smooth)
        ])
    if hyper is not None:
        cargs.extend([
            "-H",
            str(hyper)
        ])
    if verbose:
        cargs.append("-v")
    if manual_seg is not None:
        cargs.extend([
            "-s",
            execution.input_file(manual_seg)
        ])
    if iters_afterbias is not None:
        cargs.extend([
            "-O",
            str(iters_afterbias)
        ])
    cargs.extend([execution.input_file(f) for f in in_files])
    ret = FastOutputs(
        root=execution.output_file("."),
        mixeltype=execution.output_file(out_basename + "_mixeltype.nii.gz") if (out_basename is not None) else None,
        bias_field=execution.output_file(out_basename + "_bias.nii.gz") if (out_basename is not None) else None,
        partial_volume_files=execution.output_file(out_basename + "_pve_*.nii.gz") if (out_basename is not None) else None,
        partial_volume_map=execution.output_file(out_basename + "_pveseg.nii.gz") if (out_basename is not None) else None,
        restored_image=execution.output_file(out_basename + "_restore.nii.gz") if (out_basename is not None) else None,
        tissue_class_map=execution.output_file(out_basename + "_seg.nii.gz") if (out_basename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAST_METADATA",
    "FastOutputs",
    "fast",
]
